<?php

// Check if current page is blog page
if( !function_exists( 'fastwp_gems_is_blog' ) ) {
	function fastwp_gems_is_blog() {
		if (!is_front_page() && is_home())
			return TRUE;
	}
}

// List of categories
if( !function_exists( 'fastwp_gems_get_category_list' ) ) {
    function fastwp_gems_get_category_list( $strip_tags = false, $separator = ' / ' ) {
        $categories_list = get_the_category_list( $separator );
        if( $strip_tags == true ) {
            return strip_tags( $categories_list );
        } else {
            return $categories_list;
        }

    }
}

// List of categories for a post with custom posts
if( !function_exists( 'fastwp_gems_get_post_category_list' ) ) {
    function fastwp_gems_get_post_category_list( $strip_tags = false, $separator = ', ', $taxonomy = 'portfolio-category' ) {
        $categories_list = get_the_term_list( get_the_ID(), $taxonomy, '', $separator, '' );
        if( $strip_tags == true ) {
            return strip_tags( $categories_list );
        } else {
            return $categories_list;
        }
    }
}

// List of categories for a post with custom posts with array return
if( !function_exists( 'fastwp_gems_get_post_category_list_array' ) ) {
    function fastwp_gems_get_post_category_list_array( $taxonomy = 'portfolio-category' ) {
        $categories_list = get_the_terms( get_the_ID(), $taxonomy );
        $list = array();
        if( !empty( $categories_list ) ) {
            foreach( $categories_list as $category ) {
                $list[$category->slug] = $category->name;
            }
        }
        return $list;
    }
}

// List of categories for custom posts with array return
if( !function_exists( 'fastwp_gems_get_category_list_array' ) ) {
    function fastwp_gems_get_category_list_array( $args = array(), $taxonomy = 'portfolio-category', $hide_empty = true ) {
        $categories_list = get_terms( array_merge(  array( 'taxonomy' => $taxonomy, 'hide_empty' => $hide_empty ), $args ) );
        $list = array();
        if( !empty( $categories_list ) ) {
            foreach( $categories_list as $category ) {
                $list[$category->slug] = $category->name;
            }
        }
        return $list;
    }
}

// Pagination on post page
if ( !function_exists( 'fastwp_gems_post_pagination' ) ) {
    function fastwp_gems_post_pagination( $show_title = false ) {
        $prev_post = get_previous_post();
        $next_post = get_next_post();

        if( empty( $prev_post ) && empty( $next_post ) ) {
            return;
        }

        $markup = '<div class="row">
          <div class="small-12 columns">
            <div class="postNav clearfix">';

            if( !empty( $prev_post ) ) {
              $markup .= '<a href="' . get_the_permalink( $prev_post->ID ) . '" class="prevPost">
                <span class="icon-arrow-left float-left"></span>
                <div class="postNavTitle">
                  <span>Previous Post:</span>
                  <p>' . $prev_post->post_title . '</p>
                </div>
              </a>';
            }

            if( !empty( $next_post ) ) {
              $markup .= '<a href="' . get_the_permalink( $next_post->ID ) . '" class="nextPost">
                <span class="icon-arrow-right float-right"></span>
                <div class="postNavTitle">
                  <span>Next Post:</span>
                  <p>' . $next_post->post_title . '</p>
                </div>
              </a>';
            }

            $markup .= '</div>
          </div>
        </div>';

        return $markup;
    }
}

// Pagination on post page
if ( !function_exists( 'fastwp_gems_index_pagination' ) ) {
    function fastwp_gems_index_pagination( $show_title = false ) {
        if( is_singular() )
            return;

        global $wp_query;

        /** Stop execution if there's only 1 page */
        if( $wp_query->max_num_pages <= 1 )
            return;

        $paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
        $max   = intval( $wp_query->max_num_pages );

        /** Add current page to the array */
        if ( $paged >= 1 )
            $links[] = $paged;

        /** Add the pages around the current page to the array */
        if ( $paged >= 3 ) {
            $links[] = $paged - 1;
            $links[] = $paged - 2;
        }

        if ( ( $paged + 2 ) <= $max ) {
            $links[] = $paged + 2;
            $links[] = $paged + 1;
        }

        echo '<div class="row marginTop marginBottom">
        <div class="small-12 columns">
        <ul class="pagination text-center" role="navigation" aria-label="Pagination">' . "\n";

        if ( get_previous_posts_link() ) {
            printf( '<li>%s</li>' . "\n", get_previous_posts_link() );
        } else {
            echo '<li class="pagination-prev disabled">&#171; Previous Page</li>' . "\n";
        }

        if ( ! in_array( 1, $links ) ) {
            $class = 1 == $paged ? ' class="current"' : '';

            printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );

            if ( ! in_array( 2, $links ) )
                echo '<li class="ellipsis" aria-hidden="true"></li>';
        }

        sort( $links );
        foreach ( (array) $links as $link ) {
            $class = $paged == $link ? ' class="current"' : '';
            printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
        }

        if ( ! in_array( $max, $links ) ) {
            if ( ! in_array( $max - 1, $links ) )
                echo '<li class="ellipsis" aria-hidden="true"></li>' . "\n";

            $class = $paged == $max ? ' class="current"' : '';
            printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
        }

        if ( get_next_posts_link() ) {
            printf( '<li>%s</li>' . "\n", get_next_posts_link() );
        } else {
            echo '<li class="pagination-next disabled">Next Page &#187;</li>' . "\n";
        }

        echo '</ul>
        </div>
      </div>' . "\n";

    }
}

if ( !function_exists( 'fastwp_gen_author_social_networks' ) ) {
    function fastwp_gen_author_social_networks( $user_id = false ) {
        $sn_links = '';

        $profile_sn = get_the_author_meta( 'social_networks', $user_id );
        if( !empty( $profile_sn['icon'] ) ) {
            foreach( $profile_sn['icon'] as $k => $icon ) {
                if( !empty( $icon ) ) {
                    $sn_links .= sprintf( '<a href="%s"> <i class="%s"></i></a>', esc_url( $profile_sn['url'][$k] ), esc_html( $icon ) );
                }
            }
        }

        $markup = '';
        if( !empty( $sn_links ) ) {
            $markup .= $sn_links;
        }

        return $markup;
    }
}

// Related posts
if ( !function_exists( 'fastwp_gems_related_posts' ) ) {
    function fastwp_gems_related_posts() {
        global $fastwp_gems_data;
        $markup = '';

        $related_ids = get_post_meta( get_the_ID(), 'post_related', true );
        if( !empty( $related_ids ) ) {

            $markup .= '<div class="row">
                          <div class="small-12 columns">
                            <div class="divider"></div>
                          </div>
                        </div>';

            $posts = new WP_Query( array( 'post__in' => $related_ids ) );
            if( $posts->have_posts() ) {

                $markup .= '<div class="relatedPosts">
                <h5 class="title">' . esc_html__( 'Related Posts', 'gems' ) . '</h5>
                <div class="row">';

                while( $posts->have_posts() ) {

                    $posts->the_post();

                    $markup .= '<div class="small-12 medium-4 columns">
                                  <div class="blogItem">
                                    <article>
                                      <a href="' . get_the_permalink() . '"><img src="' . get_the_post_thumbnail_url( get_the_ID(), 'full' ) . '" alt="" /></a>
                                      <div class="blogItemMeta">
                                        <p class="postCategory">' . fastwp_gems_get_category_list( false, ', ' ) . '</p>
                                        <p class="postDate">' . ( !empty( $fastwp_gems_data['fwp_blog_date_meta'] ) ? get_the_date() : '' ) . '</p>
                                      </div>
                                      <h3 class="postHeadline"><a href="' . get_the_permalink() . '">' . get_the_title() . '</a></h3>
                                    </article>
                                  </div>
                                </div>';

                }

                wp_reset_postdata();

                $markup .= '</div>
                </div>

                <div class="row">
                  <div class="small-12 columns">
                    <div class="divider"></div>
                  </div>
                </div>';

            }

        }

        return $markup;
    }
}

// Pagination on index page
if ( !function_exists( 'fastwp_gems_index_pagination' ) ) {
    function fastwp_gems_index_pagination() {
        global $fastwp_gems_data;
        if( isset( $fastwp_gems_data['blog_index_item_bg'] ) ) {
            $fastwp_gems_item_bg = FastwpGemsShortcodeUtils::is_valid( 'colors', $fastwp_gems_data['blog_index_item_bg'], 'bgWhite' );
        } else {
            $fastwp_gems_item_bg = ' bgWhite';
        }
        $markup = '<div class="' . $fastwp_gems_item_bg . '">
        <div class="row padding blogPagination">
        <div class="small-12 columns clearfix">';

        if( get_previous_posts_link() ) {
             $markup .= '<div class="float-left">
                <a class="button ' . ( $fastwp_gems_item_bg == 'bgBlack' ? 'btnWhite' : 'btnBlack' ) . ' hollow small" href="' . get_previous_posts_page_link() . '"><i class="icon-angle-left iconLeft"></i> ' . esc_html__( 'Older Posts', 'gems' ) . '</a>
            </div>';
        }

        if( get_next_posts_link() ) {
            $markup .= '<div class="float-right">
                <a class="button ' . ( $fastwp_gems_item_bg == 'bgBlack' ? 'btnWhite' : 'btnBlack' ) . ' hollow small" href="' . get_next_posts_page_link() . '">' . esc_html__( 'Newer Posts', 'gems' ) . ' <i class="iconRight icon-angle-right"></i></a>
            </div>';
        }

        $markup .= '</div>
        </div>
        </div>';

        return $markup;
    }
}

// Get posts
if ( ! function_exists( 'fastwp_gems_posts' ) ) {
	function fastwp_gems_posts() {
	global $fastwp_gems_data;

        if( isset( $fastwp_gems_data['blog_layout'] ) && $fastwp_gems_data['blog_layout'] == 'masonry' ) {
            $layout = 'masonry';
        } else {
            $layout = 'list';
        }

        $columns = isset( $fastwp_gems_data['blog_index_columns'] ) && in_array( $fastwp_gems_data['blog_index_columns'], array( 2, 3, 4 ) ) ? $fastwp_gems_data['blog_index_columns'] : 2;

        if ( have_posts() ) :

            if( $layout == 'masonry' ) {
                echo '<div class="row marginTop">
                <ul class="blogMasonry blogMasonry-' . $columns . '">';
            } else {
                echo '<div class="row marginTop">
                <div class="small-12 columns noPadding">
                <div class="blogList">';
            }

        	while ( have_posts() ) : the_post();
                do_action( 'fastwp_gems_before_post_content' );

                if( $layout == 'masonry' ) {
                    get_template_part( 'extend-helpers/masonry' );
                } else {
                    get_template_part( 'extend-helpers/list' );
                }

                do_action( 'fastwp_gems_after_post_content' );
            endwhile;

            if( $layout == 'masonry' ) {
                echo '</ul>
                </div>';
            } else {
                echo '</div>
                </div>
                </div>';
            }

    	else:
    	    get_template_part('extend-helpers/content', 'none');
    	endif;
	}
}

// Share message on single
if ( !function_exists( 'fastwp_gems_share_description' ) ) {
    function fastwp_gems_share_description() {
        global $fastwp_gems_data;
        if( !isset( $fastwp_gems_data['fwp_share_description'] ) ) {
            return '';
        }
        return str_replace( array( '%TITLE%' ), array( get_the_title() ), esc_html( $fastwp_gems_data['fwp_share_description'] ) );
    }
}

// Video post
if ( ! function_exists( 'fastwp_gems_video_post' ) ) {
    function fastwp_gems_video_post( $url, $html = '' ) {
        if( !empty( $html ) ) {
            return $html;
        }

    	if( preg_match( '/http(s)?:\/\/(www.)?youtube.com/i', $url ) ) {
    	    preg_match( '/http(s)?:\/\/(www.)?youtube.com\/watch\?v=([a-z0-9-_]+)/i', $url, $video );
            if( isset( $video[3] ) ) {
                $url = 'https://www.youtube.com/embed/' . $video[3];
            }
    	} else if( preg_match( '/http(s)?:\/\/(www.)?youtu.be/i', $url ) ) {
    	    preg_match( '/http(s)?:\/\/(www.)?youtu.be\/([a-z0-9-_]+)/i', $url, $video );
            if( isset( $video[3] ) ) {
                $url = 'https://www.youtube.com/embed/' . $video[3];
            }
    	} else if( preg_match( '/http(s)?:\/\/(www.)?vimeo.com/i', $url ) ) {
    	    preg_match( '/http(s)?:\/\/(www.)?vimeo.com\/([0-9]+)/i', $url, $video );
            if( isset( $video[3] ) ) {
                $url = 'https://player.vimeo.com/video/' . $video[3];
            }
    	}

        if( !empty( $url ) ) {
            echo '<iframe src="'. esc_url( $url ) .'" webkitallowfullscreen="" mozallowfullscreen="" allowfullscreen="" frameborder="0" height="315" width="560"></iframe>';
        }
    	return;
    }
}

// Comment form
if( !function_exists( 'fastwp_gems_comment_form' ) ) {
	function fastwp_gems_comment_form() {

		global $post, $user_identity;
		if( !isset( $post->ID ) ) return;

		$commenter      = wp_get_current_commenter();
		$req            = get_option( 'require_name_email' );
		$aria_req       = ( $req ? " aria-required='true'" : '' );

		$args = array(
		  'id_submit'           => 'submit',
          'class_submit'        => 'submit-btn',
          'id_form'             => 'contactform',
          'class_form'          => 'comment-form',
		  'class_submit'        =>  'button medium bkg-theme bkg-hover-theme color-white color-hover-white no-margin-bottom',
		  'title_reply'         => '',
		  'title_reply_to'      => esc_html__( 'Leave a Reply to %s', 'gems' ),
		  'cancel_reply_link'   => esc_html__( 'Cancel Reply', 'gems' ),
		  'label_submit'        => esc_html__( 'Post Comment', 'gems' ),

		  'must_log_in' => '<p class="mleft must-log-in">' . esc_html__( 'You must be loggedin to post a comment.', 'gems' ) . '</p>',

		  'logged_in_as' => '<p class="mleft logged-in-as">' .
		    sprintf( esc_html__( 'Logged in as %s', 'gems' ), $user_identity ) . ' <a href="' . wp_logout_url( apply_filters( 'the_permalink', get_permalink( ) ) ) . '" title="' . esc_html__( 'Log out of this account', 'gems' ) . '">' . esc_html__( 'Log out?', 'gems' ) . '</a>' . '</p>',

		    'comment_notes_before' => '',

		    'comment_field' => '<textarea id="comments" name="comment" cols="45" rows="8" class="comment-field" aria-required="true" placeholder="' . esc_html_x( 'Comment', 'noun', 'gems' ) . '"></textarea>',

		    'fields' => apply_filters( 'comment_form_default_fields', array(
    		    'author'    => '<input id="name" class="form-email form-element" name="author" type="text" value="' . esc_html( $commenter['comment_author'] ) . '" size="30"' . $aria_req . '  placeholder="'. esc_html__( 'Name', 'gems' ).'"/>',
                'email'     => '<input id="email" class="form-email form-element" name="email" type="text" value="' . esc_html(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' placeholder="' . esc_html__( 'Email', 'gems' ) . '" />',
                'url'       => '<input id="website" name="url" class="form-email form-element"  type="text" value="' . esc_url( $commenter['comment_author_url'] ) . '" size="30" placeholder="' .  esc_html__( 'Website', 'gems' ) . '" />'
		        )

		  )
		);

        return comment_form( $args, $post->ID );
	}
}

// Comment template
if ( ! function_exists( 'fastwp_gems_comment' ) ) {
    function fastwp_gems_comment( $comment, $args, $depth ) {
        global $post;
        if( !isset( $post->ID ) ) return;

        $GLOBALS['comment'] = $comment;

        switch ( $comment->comment_type ) {

            case 'pingback' :
            case 'trackback' :
            ?>

            <li><p><?php esc_html_e( 'Pingback:', 'gems' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( esc_html__( 'Edit', 'gems' ), ' / <i class="edit-link">', '</i>' ); ?></p>

            <?php
            break;

            default :
            ?>

            <li>
            <div class="commentBlock clearfix">
                <div class="commentThumb float-left imgShadow">
                  <?php echo get_avatar( $comment, 90 ); ?>
                </div>
                <?php echo comment_reply_link( array_merge( $args, array( 'reply_text' => '<span class="icon-reply"></span>', 'before'=> '<span class="float-right">', 'after' => '</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
                <div class="commentMeta">
                  <span class="authorName"><?php echo get_comment_author(); ?></span>
                  <span class="commentTime smallText"><?php echo sprintf( esc_html__( 'on %s', 'gems' ), get_comment_date('F j, Y') ); ?></span>
                </div>
                <div class="clearfix"></div>
                <div class="commentContent">
                  <p class="smallText">
                    <?php if( $comment->comment_approved == 0 ) {
                        esc_html_e( 'Your comment is awaiting moderation.', 'gems' );
                    } else {
                        comment_text();
                    } ?>
                  </p>
                </div>
            </div>

            <?php break;

        }
    }
}

// End tag for comment template
if( !function_exists( 'fastwp_gems_comment_close_tag' ) ) {
	function fastwp_gems_comment_close_tag() {
	    echo '</li>';
    }
}

// Move textarea
if( !function_exists( 'fastwp_gems_move_comtextarea' ) ) {
    function fastwp_gems_move_comtextarea( $fields ) {
        $comment_field = $fields['comment'];
        unset( $fields['comment'] );
        $fields['comment'] = $comment_field;
        return $fields;
    }

    add_filter( 'comment_form_fields', 'fastwp_gems_move_comtextarea' );
}

// Get posts count
if ( !function_exists( 'fastwp_gems_posts_count' ) ) {
	function fastwp_gems_posts_count() {
		global $wp_query;
   		return $wp_query->found_posts;
	}
}

// Get number of posts per page
if ( !function_exists( 'fastwp_gems_posts_per_page' ) ) {
	function fastwp_gems_posts_per_page() {
   		return get_option( 'posts_per_page' );
	}
}

// Get current Page
if ( !function_exists( 'fastwp_gems_page_now' ) ) {
	function fastwp_gems_page_now() {
	    global $paged;
   		return ( !empty( $paged ) ? $paged : 1 );
	}
}

// Widgets init
if( !function_exists('fastwp_gems_widgets_init' ) ) {
    function fastwp_gems_widgets_init() {
    	register_sidebar( array(
    		'name'          => esc_html__( 'Main Widget Area', 'gems' ),
    		'id'            => 'sidebar-1',
    		'description'   => esc_html__( 'Appears on posts and pages in the sidebar.', 'gems' ),
    		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    		'after_widget'  => '</aside>',
    		'before_title'  => '<h3 class="widget-title">',
    		'after_title'   => '</h3>',
    	) );
    }
    add_action( 'widgets_init', 'fastwp_gems_widgets_init' );
}

// Page before footer
if( !function_exists( 'fastwp_gems_page_before_footer' ) ) {
	function fastwp_gems_page_before_footer() {
	    global $fastwp_gems_data;

        $page_id = 0;

        $fastwp_gems_meta_type = get_post_meta( get_the_ID(), 'p_footer_type', true );
        if( $fastwp_gems_meta_type == 'big' ) {
            $footer_page = get_post_meta( get_the_ID(), 'p_page_before_footer', true );
            if( !empty( $footer_page ) ) {
                $page_id = $footer_page;
            }
        } else {
            $page_id = isset( $fastwp_gems_data['page_before_footer'] ) ? $fastwp_gems_data['page_before_footer'] : '';
        }

    	if( !empty( $page_id ) ) {

            $fastwp_gems_pbf = get_post( $page_id );
            if( isset( $fastwp_gems_pbf->ID ) ) {

            echo '<div class="footerWidgets">';
            echo apply_filters( 'the_content', $fastwp_gems_pbf->post_content );
            echo '</div>';

            }

        }
    }
}