<?php

class FastwpGemsBlogPosts extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_blogposts'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode( $atts, $content ) {
		extract(shortcode_atts(array(
			'limit'			    => -1,
			'include'			=> '',
			'exclude'			=> '',
            'orderby'           => 'date',
            'order'             => 'DESC',
            'read_more_lb'      => 'Read More',
            'extra_class'       => '',
            'show_categories'   => true,
            'show_date'         => true,
            'date_format'       => 'd F'
		), $atts));

		$args = array(
			'numberposts' 		=> $limit,
			'posts_per_page' 	=> $limit,
			'post_status' 		=> 'publish',
			'post_type'			=> 'post',
            'orderby'           => $orderby,
            'order'             => $order,
			'include'			=> $include,
			'exclude'			=> $exclude,
			'suppress_filters'	=> '0'
			);

		if( $include != '' ) {
			$args['include'] = $include;
            $args['orderby'] = 'post__in';
		}

		if( $exclude != '' ) {
			$args['exclude'] = $exclude;
		}

        $items = get_posts( $args );

		if( !is_array( $items ) || ( is_array( $items ) && count( $items ) == 0 ) ) {
			return FastWP_UI::alert( 'warning', esc_html__('Used [Gems-BlogPosts] shortcode but no posts is selected. <br>Please add at least one post before using this shortcode.', 'gems' ) );
		}

        $read_more_lb   = !empty( $read_more_lb ) ? esc_html( $read_more_lb ) : 'Read More';
        $date_format    = !empty( $date_format ) ? esc_html( $date_format ) : 'd F';

        $items_markup = '<div' . ( !empty( $extra_class ) ? ' class="' . sanitize_html_class( $extra_class ) . '"' : '' ) . '>

        <div class="small-12 columns">
        <div class="blogList">';

		foreach( $items as $item ) {

        $meta               = FastwpGemsMeta::get( $item->ID );
        $date = $trms       = '';
		$title 	            = $item->post_title;
		$text 	            = $item->post_excerpt;
        $link               = get_permalink( $item->ID );
        $terms              = get_the_category( $item->ID );

        if( (boolean) $show_categories && !empty( $terms ) && is_array( $terms ) ) {
            $trms .= '<p class="postCategory">';
            foreach(  $terms as $term ) {
                $cat_link = get_category_link( $term->term_id );
                $trms .= sprintf( '<a href="%s">%s</a>', $cat_link, $term->name );
            }
            $trms .= '</p>';
        }

        if( (boolean) $show_date ) {
            $date .= sprintf( '<p class="postDate">%s</p>', date( $date_format, strtotime( $item->post_date ) ) );
        }

		$member_markup = '<div class="blogItem">
                <div class="row">
                  <div class="small-12 medium-4 columns">
                    <div class="blogItemMeta">
                      %s
                      %s
                    </div>
                  </div>

                  <div class="small-12 medium-8 columns">
                    <h3 class="postHeadline"><a href="%s">%s</a></h3>
                    %s
                    <div class="link">
                      <a href="%s">%s<span class="icon-arrow-right"></span></a>
                    </div>
                  </div>
                </div>
              </div>';

        $items_markup .= sprintf( $member_markup, $trms, $date, $link, $title, $text, $link, $read_more_lb );

        }

        $items_markup .= '</div>

        </div>
        </div>';

        return $items_markup;
    }

	public static function vc_block() {
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Blog Posts', 'gems' ),
			"base"      => 'fastwp_gems_blogposts',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"params"    => array(
				array(
					"save_always"   => true,
					"type" 			=> "dropdown",
					"holder"        => false,
					"edit_field_class"=> "w50_fastwp_vc",
					"heading" 		=> esc_html__( "Order By",'gems' ),
					"param_name" 	=> "orderby",
					"value" 		=> array(
                                            esc_html__( 'Date', 'gems' )          => 'date',
                                            esc_html__( 'Title', 'gems' )         => 'title',
                                            esc_html__( 'Random', 'gems' )        => 'rand',
                                            esc_html__( 'Menu Order', 'gems' )    => 'menu_order',
                                            esc_html__( 'Modified Date', 'gems' ) => 'modified'
                                            ),
					"default"		=> "default",
					"admin_label"	=> true,
				),
				array(
					"save_always"   => true,
					"type" 			=> "dropdown",
					"holder"        => false,
					"edit_field_class"=> "w50_fastwp_vc",
					"heading" 		=> esc_html__( "Order Type",'gems' ),
					"param_name" 	=> "order",
                    "value" 		=> array(
                                            esc_html__( 'Ascending', 'gems' )    => 'asc',
                                            esc_html__( 'Descending', 'gems' )   => 'desc'
                                            ),
					"default"		=> "default",
					"admin_label"	=> true,
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Include Posts", 'gems' ),
					"param_name" 	=> 'include',
					"admin_label"	=> true,
					"description"	=> esc_html__("Put post IDs to include only these",'gems')
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Exclude Posts", 'gems' ),
					"param_name" 	=> 'exclude',
					"admin_label"	=> true,
					"description"	=> esc_html__("Put post IDs to exclude only these",'gems')
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Limit",'gems' ),
					"param_name" 	=> 'limit',
					"value" 		=> '-1',
					"admin_label"	=> true,
					"description"	=> esc_html__( "How many posts do you need to show here. (-1 = all)", 'gems' )
				),
				array(
					"type" 			=> "dropdown",
					"holder"        => false,
					"heading" 		=> esc_html__( "Show Categories", 'gems' ),
					"param_name" 	=> "show_categories",
					"value" 		=> array(
                                            esc_html__( 'Yes', 'gems' ) => 1,
                                            esc_html__( 'No', 'gems' ) => 0
                                            ),
					"admin_label"   => true,
				),
				array(
					"type" 			=> "dropdown",
					"holder"        => false,
					"heading" 		=> esc_html__( "Show Categories", 'gems' ),
					"param_name" 	=> "show_date",
					"value" 		=> array(
                                            esc_html__( 'Yes', 'gems' ) => 1,
                                            esc_html__( 'No', 'gems' ) => 0
                                            ),
					"admin_label"   => true,
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Date Format", 'gems' ),
					"param_name" 	=> 'date_format',
					"value" 		=> 'd F',
					"admin_label"	=> true,
					"description"	=> "Default: 'd F'. (example: <b>d.m.Y, H:i:s = " . date( 'd.m.Y, H:i:s' ) . "</b>, <b>d F = " . date( 'd F' ) . "</b>)",
                    "dependency"    => array( "element" => "show_date", "value" => array( "1" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Extra Class", 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Use this options to add an extra class to element, you can use this for custom css", 'gems' )
				)
 			)
        );

	}

}

?>