<?php

class FastwpGemsButton extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_button'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode( $atts, $content ) {
		extract(shortcode_atts(array(
			'button'		=> '',
            'url'           => '',
            'size'          => 'basic',
			'btn_class'		=> '',
			'btn_bg'        => 'rgb(78, 74, 207)',
			'btn_bg_hov'    => 'rgba(76, 72, 207, 0.9)',
		    'label_color'	=> '#fff',
			'label_hov_col'	=> '#fff',
			'alignment'		=> 'inline-block',
            'margin_left'   => 0,
            'margin_right'  => 0,
			'margin_top'	=> 0,
			'margin_bottom'	=> 0,
            'icon'          => '',
            'icon_align'    => '',
            'is_modal'      => false,
            'modal_type'    => 'content',
            'modal_iframe'  => '',
			'extra_class'	=> ''
		), $atts));

        $class = array();

		$class[] = $button_id = 'fwp-btn-' . rand( 1000, 9999 );

        $link = FastwpGemsUtils::url_from_vc( $url );

        list( $label, $url, $target ) = array( $link['title'], $link['url'], $link['target'] );

        if( !empty( $icon ) ) {
            $label = $icon_align != 'right' ? '<span class="' . esc_attr( $icon ) . ' iconLeft"></span> ' . esc_html( $label ) : esc_html( $label ) . ' <span class="' . esc_attr( $icon ) . ' iconRight"></span>';
        }

        if( !empty( $btn_class ) ) {
            $class[] = esc_attr( $btn_class );
        } else {
            // custom style for button
            self::add_css( sprintf('.%s{color:%s; background-color:%s;}', $button_id, esc_html( $label_color ), esc_html( $btn_bg ) ) );
            self::add_css(  sprintf('.%s:hover{color:%s; background-color:%s;}', $button_id, esc_html( $label_hov_col ), esc_html( $btn_bg_hov ) ) );
        }

        if( !empty( $size ) ) {
            $class[] = esc_attr( $size );
        }

        if( !empty( $extra_class ) ) {
            $class[] = esc_attr( $extra_class );
        }

        $modal_id = rand( 1, 9999 );

        if( !in_array( $alignment, array( 'left', 'right', 'center' ) ) ) {

		$button = sprintf( '<a %s class="button %s">
                		<span>%s</span>
        			</a>', ( (boolean) $is_modal ? 'data-open="Modal' . $modal_id . '"' : 'href="' . esc_url( $url ) . '" target="' . esc_attr( $target ) . '"' ), implode( ' ', $class ), $label );

        } else {

        if( $margin_top != ''  || $margin_bottom != '' || !empty( $alignment ) ) {
            self::add_css(  sprintf( '.fwp_button_%s{text-align:%s; margin:%spx %spx %spx %spx!important;}', $button_id, ( in_array( $alignment, array( 'left', 'center', 'right' ) ) ? $alignment : 'left' ), (int) $margin_top, (int) $margin_right, (int) $margin_bottom, (int) $margin_left ) );
        }

		$button = sprintf( '<div class="fwp_button_%s">
            		<a %s class="button %s">
                		<span>%s</span>
        			</a>
			    </div>', $button_id, ( (boolean) $is_modal ? 'data-open="Modal' . $modal_id . '"' : 'href="' . esc_url( $url ) . '" target="' . esc_attr( $target ) . '"' ), implode( ' ', $class ), $label );

        }

        if( (boolean) $is_modal ) {

        if( $modal_type == 'iframe' ) {
            $content = sprintf( '<div class="flex-video widescreen vimeo">
                      <iframe src="%s" width="400" height="225" allowFullScreen></iframe>
                    </div>', esc_url( $modal_iframe ) );
        }

        $button .= sprintf( '<div class="reveal large boxShadow" id="Modal%s" data-reveal data-animation-in="fade-in" data-animation-out="fade-out">
                    %s
                    <button class="close-button" data-close aria-label="Close modal" type="button">
                      <span class="icon-cross" aria-hidden="true"></span>
                    </button>
                  </div>', $modal_id, $content );

        }

        return $button;
    }

	public static function vc_block() {
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Button', 'gems' ),
			"base"      => 'fastwp_gems_button',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"params"    => array(
				array(
					"save_always" 	=> true,
					"type" 			=> 'vc_link',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "URL", 'gems' ),
					"param_name" 	=> "url",
					"admin_label"	=> false,
					"description" 	=> esc_html__("Choose button URL and settings",'gems')
				 ),
				 array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Button Alignment", 'gems' ),
					"param_name" 	=> 'alignment',
					'value'			=> array(
        							        'Inline (without wrapper)' => 'inline-block',
        							        'Left (with wrapper)'   => 'left',
        							        'Center (with wrapper)' => 'center',
        							        'Right (with wrapper)'  => 'right',
        							    	),
					"default" 		=> 'inline-block',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose button alignment. Default: Inline (without wrapper)",'gems')
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'iconpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Icon",'gems'),
		            'param_name'    => 'icon',
					"admin_label"	=> true,
		            'settings'      => array(
            		                        'emptyIcon'    => true,
                                            'type'         => 'icomoon',
            		                        'iconsPerPage' => 200
        		                            ),
		             "description" 	=> esc_html__("Choose what icon do you want to use (icomoon icons).",'gems')
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Icon Align", 'gems' ),
					"param_name" 	=> 'icon_align',
					'value'			=> array(
							        'Left'   => 'left',
							        'Right'  => 'right'
							    	),
					"default" 		=> 'left',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose icon alignment. Default: Left",'gems')
				),
			    array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Button Style",'gems'),
					"param_name" 	=> "btn_class",
					'value'			=> array(
        							        'Custom'                => '',
        							        'Primary Button'        => 'primary',
        							        'Primary Ghost Button'  => 'primary hollow',
        							        'Secondary Button'      => 'secondary',
        							        'Secondary Ghost Button'=> 'secondary hollow',
        							        'Success Button'        => 'success',
        							        'Success Ghost Button'  => 'success hollow',
        							        'Alert Button'          => 'alert',
        							        'Alert Ghost Button'    => 'alert hollow',
        							        'Warning Button'        => 'warning',
        							        'Warning Ghost Button'  => 'warning hollow'
        							    	),
					"default" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose the style for this button",'gems')
			    ),
			    array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Button size",'gems'),
					"param_name" 	=> "size",
					'value'			=> array(
        							        'Basic'                 => '',
        							        'Tiny'                  => 'tiny',
        							        'Small'                 => 'small',
        							        'Large'                 => 'large',
        							        'Expanded '              => 'expanded',
        							        'Small Expanded'        => 'small expanded'
        							    	),
					"default" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose the size for this button.",'gems')
			    ),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Label Color",'gems'),
					"param_name" 	=> 'label_color',
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Modify label color for default state",'gems'),
                    "dependency"    => array( "element" => "btn_class", "value" => array( "" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Label Color Hover",'gems'),
					"param_name" 	=> "label_hov_col",
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Modify label color for hover state",'gems'),
                    "dependency"    => array( "element" => "btn_class", "value" => array( "" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Background Color",'gems'),
					"param_name" 	=> 'btn_bg',
					"value" 		=> 'rgb(78, 74, 207)',
					"admin_label"	=> true,
					"description"	=> esc_html__("Modify background color for default state",'gems'),
                    "dependency"    => array( "element" => "btn_class", "value" => array( "" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Background Color Hover",'gems'),
					"param_name" 	=> 'btn_bg_hov',
					"value" 		=> 'rgba(76, 72, 207, 0.9)',
					"admin_label"	=> true,
					"description"	=> esc_html__("Modify background color for hover state",'gems'),
                    "dependency"    => array( "element" => "btn_class", "value" => array( "" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"edit_field_class"=> "w25_fastwp_vc",
					"heading" 		=> esc_html__( "Margin Top", 'gems' ),
					"param_name" 	=> 'margin_top',
					"admin_label"	=> true,
					"description"	=> esc_html__("Only numeric values (px)",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"edit_field_class"=> "w25_fastwp_vc",
					"heading" 		=> esc_html__( "Margin Right", 'gems' ),
					"param_name" 	=> 'margin_right',
					"admin_label"	=> true,
					"description"	=> esc_html__("Only numeric values (px)",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"edit_field_class"=> "w25_fastwp_vc",
					"heading" 		=> esc_html__("Margin Bottom",'gems'),
					"param_name" 	=> 'margin_bottom',
					"admin_label"	=> true,
					"description"	=> esc_html__("Only numeric values (px)",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"edit_field_class"=> "w25_fastwp_vc",
					"heading" 		=> esc_html__("Margin Left",'gems'),
					"param_name" 	=> 'margin_left',
					"admin_label"	=> true,
					"description"	=> esc_html__("Only numeric values (px)",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Modal', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Use it as Popup/Modal",'gems'),
					"param_name" 	=> 'is_modal',
					'value'			=> array(
        							        esc_html__( 'No', 'gems' )   => 0,
        							        esc_html__( 'Yes', 'gems' )  => 1,
        							    	),
					"default" 		=> '0',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Choose to use this button as a popup trigger", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Modal', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Modal Content", 'gems' ),
					"param_name" 	=> 'modal_type',
					'value'			=> array(
        							        esc_html__( 'Text', 'gems' )     => 'content',
        							        esc_html__( 'Iframe', 'gems' )   => 'iframe'
        							    	),
					"default" 		=> 'content',
					"admin_label"	=> true,
					"description"	=> esc_html__("The content",'gems'),
                    "dependency"    => array( "element" => "is_modal", "value" => array( "1" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Modal', 'gems' ),
					"type" 			=> 'textarea_html',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Content",'gems'),
					"param_name" 	=> 'content',
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("This text will appear into the modal",'gems'),
                    "dependency"    => array( "element" => "modal_type", "value" => array( "content" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Modal', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Iframe URL",'gems'),
					"param_name" 	=> 'modal_iframe',
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Iframe URL to appear into the modal",'gems'),
                    "dependency"    => array( "element" => "modal_type", "value" => array( "iframe" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Extra Class", 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__("Use this options to add an extra class to element, you can use this for custom css",'gems')
				)
 			)
        );

	}

}

?>