<?php

class FastwpGemsCalloutMessage extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_callout_message'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode( $atts, $content ) {
		global $fwp_custom_shortcode_css;
		extract(shortcode_atts(array(
            'message'       => 'This is a message ...',
            'close_button'  => false,
            'tag'           => 'h5',
            'show_border'   => true,
            'border'        => '',
            'background'    => '',
            'alignment'     => 'left',
            'style'         => 'default',
            'extra_class'   => ''
		), $atts));

        $class = array();

		$class[] = $callout_id = 'fwp-callout-' . rand( 1000, 9999 );

        if( in_array( $style, array( 'default', 'secondary', 'alert', 'success', 'warning' ) ) ) {
            $class[] = $style;
        }

        if( !empty( $extra_class ) ) {
            $class[] = esc_attr( $extra_class );
        }

        if( !in_array( $tag, array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'msg' ) ) ) {
            $tag = 'h2';
        }

        // set new style to this callout
        if( !empty( $border ) && (boolean) $show_border ) {
            self::add_css( sprintf('.%s{border-color:%s;}', $callout_id, esc_html( $border ) ) );
        }
        if( !empty( $background ) ) {
            self::add_css(  sprintf('.%s{background:%s;}', $callout_id, esc_html( $background ) ) );
        }

        if( $tag == 'msg' ) {

            $clb_text = '';
            if( (boolean) $close_button ) {
                $clb_text = '<button class="close-button" aria-label="Dismiss alert" type="button" data-close>
                          <span aria-hidden="true">&times;</span>
                        </button>';
            }

            return sprintf( '<div class="callout %s">
                                %s
                                %s
                            </div>', implode( ' ', $class ), $content, $clb_text );

        } else {

            return sprintf( '<div class="callout %s">
                                <%s>%s</%s>
                            </div>', implode( ' ', $class ), $tag, esc_html( $message ), $tag );

        }
    }

	public static function vc_block() {
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Callout Message', 'gems' ),
			"base"      => 'fastwp_gems_callout_message',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"params"    => array(
				array(
					"save_always" 	=> true,
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Message", 'gems' ),
					"param_name" 	=> 'message',
					"value" 		=> 'This is a message ...',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Put your message here", 'gems' ),
                    "dependency"    => array( "element" => "tag", "value" => array( "h1", "h2", "h3", "h4", "h5", "h6" ) )
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'textarea_html',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Message", 'gems' ),
					"param_name" 	=> 'content',
					"value" 		=> 'This is a message ...',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Put your message here", 'gems' ),
                    "dependency"    => array( "element" => "tag", "value" => array( "msg" ) )
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Tag", 'gems' ),
					"param_name" 	=> 'tag',
					'value'			=> array(
        							        'H1'        => 'h1',
        							        'H2'        => 'h2',
        							        'H3'        => 'h3',
        							        'H4'        => 'h4',
        							        'H5'        => 'h5',
        							        'H6'        => 'h6',
                                            'Message'   => 'msg'
        							    	),
					"default" 		=> 'h5',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Choose a tag or select to show a message and not a tag.", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Show Close Button", 'gems' ),
					"param_name" 	=> 'close_button',
					'value'			=> array(
        							        esc_html__( 'Yes', 'gems' )   => 1,
        							        esc_html__( 'No', 'gems' )    => 0
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Choose to show or hide close button. Default: Yes (visible)", 'gems' ),
                    "dependency"    => array( "element" => "tag", "value" => array( "msg" ) )
				),
    			array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Title Alignment",'gems'),
					"param_name" 	=> 'alignment',
					'value'			=> array(
        							        esc_html__( 'Left', 'gems' )   => 'left',
        							        esc_html__( 'Center', 'gems' ) => 'center',
        							        esc_html__( 'Right', 'gems' )  => 'right',
        							    	),
					"default" 		=> 'left',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose message alignment. Default: Left",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Style", 'gems' ),
					"param_name" 	=> 'style',
					'value'			=> array(
        							        'Default'   => 'default',
        							        'Secondary' => 'secondary',
                                            'Alert'     => 'alert',
                                            'Success'   => 'success',
                                            'Warning'   => 'warning',
        							        'Custom'    => 'custom'
        							    	),
					"default" 		=> 'default',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Choose line alignment or possition. Default: Left", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Show Border",'gems'),
					"param_name" 	=> 'show_border',
					'value'			=> array(
        							        esc_html__( 'Yes', 'gems' )   => 1,
        							        esc_html__( 'No', 'gems' )    => 0,
							    	        ),
					"default" 		=> '1',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Choose to show or hide border. Default: Yes (visible)", 'gems' ),
                    "dependency"    => array( "element" => "style", "value" => array( "custom" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Border Color", 'gems' ),
					"param_name" 	=> "border",
					"admin_label"	=> true,
					"description"	=> esc_html__("Modify border color",'gems'),
                    "dependency"    => array( "element" => "show_border", "value" => array( "1" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Background Color", 'gems' ),
					"param_name" 	=> 'background',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Modify background color", 'gems' ),
                    "dependency"    => array( "element" => "style", "value" => array( "custom" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Extra Class",'gems'),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__("Use this options to add an extra class to element, you can use this for custom css",'gems')
				),
 			)
        );

	}

}

?>