<?php

class FastwpGemsContentSlider extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_content_slider_container'] = array( 'class' => __CLASS__, 'function' => 'shortcode_container' );
		$fastwp_gems_shortcodes['fastwp_gems_content_slider_item'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode_container( $atts, $content ) {
        global $content_slider_itms;
        $content_slider_itms = 0;

		extract(shortcode_atts(array(
            'next_prev'     => true,
            'bullets'       => true,
			'extra_class'	=> ''
		), $atts));

        $shortcode = do_shortcode( $content );

		$markup = '<div class="orbit%s" role="region" aria-label="" data-orbit="">';

        if( (boolean) $next_prev ) {

            $markup .= '<button class="icon-long-arrow-left orbit-previous"><span class="show-for-sr">Previous Slide</span></button>
            <button class="icon-long-arrow-right orbit-next"><span class="show-for-sr">Next Slide</span></button>';

        }

        $markup .= '<ul class="orbit-container">
            %s
        </ul>';

        if( (boolean) $bullets ) {

            $markup .= '<nav class="orbit-bullets show-for-large">';
            for( $i = 0; $i < $content_slider_itms; $i++ ) {
              $markup .= sprintf( '<button%s data-slide="%s"></button>', ( $i == 0 ? ' class="is-active"' : '' ), $i );
            }
            $markup .= '</nav>';

        }

        $markup .= '</div>';

        return sprintf( $markup, ( !empty( $extra_class ) ? ' ' . sanitize_html_class( $extra_class ) : '' ), $shortcode );
    }

	public static function shortcode( $atts, $content ) {
		global $content_slider_itms;
		extract(shortcode_atts(array(
            'title'         => 'Title',
            'style'         => 'bgGray',
            'background_color'=> '',
            'visibility'    => true,
            'extra_class'   => ''
		), $atts));

        if( ! (boolean) $visibility ) return '';

        $content_slider_itms++;

        $class = array();

		$class[] = $item_id = 'fwp_content_slide_' . rand( 1000, 9999 );

        $class['def_style'] = 'bgGray';
        if( in_array( $style, array( 'bgBlack', 'bgColor' ) ) ) {
            $class['def_style'] = $style;
        }

        $class[] = 'padding';

        if( !empty( $extra_class ) ) {
            $class[] = esc_attr( $extra_class );
        }

        $item_markup = '<li class="orbit-slide">
                        <div class="%s">
                          <h2>%s</h2>
                          <p>%s</p>
                        </div>
                      </li>';

        // set new style to this title
        if( !empty( $background_color ) ) {
            self::add_css( sprintf('.%s{background:%s;}', $item_id, esc_html( $background_color ) ) );
        }

		return sprintf( $item_markup, implode( ' ', $class ), esc_html( $title ), $content );
    }

	public static function vc_block(){
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			'name'                      => esc_html__( 'Content Slider', 'gems' ),
			'base'                      => 'fastwp_gems_content_slider_container',
			"icon"                      => get_template_directory_uri() . "/assets/img/logo-square.png",
			'as_parent'                 => array('only' => 'fastwp_gems_content_slider_item'),
            'category'                  => esc_html__('Gems Elements', 'gems'),
			'content_element'           => true,
			'show_settings_on_create'   => false,
			"params"                    => array(
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Next Preview Buttons", 'gems' ),
					"param_name" 	=> "next_prev",
					'value'			=> array(
        							        esc_html__( 'Visible', 'gems' )  => 1,
        						            esc_html__( 'Hidden', 'gems' )   => 0
							    	),
					"default" 		=> '1',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Bullets Navigation", 'gems' ),
					"param_name" 	=> "bullets",
					'value'			=> array(
        							        esc_html__( 'Visible', 'gems' )  => 1,
        						            esc_html__( 'Hidden', 'gems' )   => 0
							    	),
					"default" 		=> '1',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Extra Class", 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__("Use this options to add an extra class to element, you can use this for custom css",'gems')
				)
		    ),
			'js_view' => 'VcColumnView'
		);

		$fastwp_gems_visual_composer_blocks[] = array(
 			'name'              => esc_html( 'Content Slider Item', 'gems' ),
			'base'              => 'fastwp_gems_content_slider_item',
			"icon"              => get_template_directory_uri() . "/assets/img/logo-square.png",
			'as_child'          => array('only' => 'fastwp_gems_content_slider_container' ),
            'category'          => esc_html__('Gems Elements', 'gems'),
			'content_element'   => true,
			'params'            => array(
				array(
					"save_always"   => true,
					'type'          => 'textfield',
					'holder'        => 'div',
					'heading'       => esc_html__( 'Title', 'gems' ),
					'param_name'    => 'title',
					'value'         => 'Slide Title',
				),
				array(
					"save_always"   => true,
					'type'          => 'textarea_html',
					'holder'        => 'div',
					'heading'       => esc_html__( 'Content', 'gems' ),
					'param_name'    => 'content',
					'value'         => 'Slider Content Here ...',
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Visibility", 'gems' ),
					"param_name" 	=> "visibility",
					'value'			=> array(
        							        esc_html__( 'Visible', 'gems' )  => 1,
        						            esc_html__( 'Hidden', 'gems' )   => 0
							    	        ),
					"default" 		=> '1',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Box Style", 'gems' ),
					"param_name" 	=> "style",
					'value'			=> array(
                                            'Custom'  => '',
        							        'Black'   => 'bgBlack',
        						            'Gray'    => 'bgGray',
        						            'Blue'    => 'bgColor',
        							    	),
					"default" 		=> 'bgGray',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Background Color",'gems'),
					"param_name" 	=> 'background_color',
					"admin_label"	=> true,
					"description"	=> esc_html__("Default: #151515",'gems'),
                    "dependency"    => array( "element" => "style", "value" => array( "" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Extra Class", 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__("Use this options to add an extra class to element, you can use this for custom css",'gems')
				)
			)
		);
	}

}

if ( class_exists( 'WPBakeryShortCodesContainer' ) ) { class WPBakeryShortCode_fastwp_gems_content_slider_container extends WPBakeryShortCodesContainer { } }
if ( class_exists( 'WPBakeryShortCode' ) ) { class WPBakeryShortCode_fastwp_gems_content_slider_item extends WPBakeryShortCode { } }

?>