<?php

class FastwpGemsCountdown extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_countdown'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode( $atts, $content ) {
		extract(shortcode_atts(array(
            'stop_year'     => date('Y'),
			'stop_month'	=> date('F'),
			'stop_day'		=> date('j'),
            'stop_hour'     => date('G'),
            'stop_minute'   => date('s'),
            'digits_color'  => '',
            'text_color'    => '',
            'extra_class'   => ''
		), $atts));

		$counter_id = 'fwp-countdown-' . rand( 1000, 9999 );
        $date       = date( 'd F Y, H:i', strtotime( implode( ' ', array( $stop_day, $stop_month, $stop_year, ', ' . $stop_hour . ':' . $stop_minute ) ) ) );

        $item_markup = '<div>
          <div class="small-12 medium-12 columns%s">
            <div class="countdown" id="%s"></div>
            <script>

            jQuery(document).on("ready", function() {
                jQuery("#%s").countdown({until: new Date("%s")});
            });

            </script>
          </div>
        </div>';

        // set new style to this team member
        if( !empty( $digits_color ) ) {
            self::add_css( sprintf('#%s .countdown-amount{color:%s;}', $counter_id, esc_html( $digits_color ) ) );
        }
        if( !empty( $text_color ) ) {
            self::add_css( sprintf('#%s .countdown-period{color:%s;}', $counter_id, esc_html( $text_color ) ) );
        }

		return sprintf( $item_markup,  ( !empty( $extra_class ) ? ' ' . sanitize_html_class( $extra_class ) : '' ), $counter_id, $counter_id, $date );
    }

	public static function vc_block() {
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Countdown', 'gems' ),
			"base"      => 'fastwp_gems_countdown',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"params"    => array(
				array(
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"edit_field_class"=> "w20_fastwp_vc",
					"heading"       => esc_html__("Stop Year",'gems'),
					"param_name"    => "stop_year",
					"value"         => date( 'Y' ),
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"type" 			=> "dropdown",
					"holder"        => false,
					"edit_field_class"=> "w20_fastwp_vc",
					"heading" 		=> esc_html__( "Stop Month", 'gems' ),
					"param_name" 	=> "stop_month",
					"value" 		=> array( 'January' => 'January', 'February' => 'February', 'March' => 'March', 'April' => 'April', 'May' => 'May', 'June' => 'June', 'July' => 'July', 'August' => 'August', 'September' => 'September', 'October' => 'October', 'November' => 'November', 'December' => 'December' ),
					"default"		=> "default",
					"admin_label"	=> true,
				),
				array(
					"save_always"   => true,
					"type" 			=> "dropdown",
					"holder"        => false,
					"edit_field_class"=> "w20_fastwp_vc",
					"heading" 		=> esc_html__( "Stop Day", 'gems' ),
					"param_name" 	=> "stop_day",
					"value" 		=> range( 1, 31 ),
					"default"		=> "default",
					"admin_label"	=> true,
				),
				array(
					"save_always"   => true,
					"type" 			=> "dropdown",
					"holder"        => false,
					"edit_field_class"=> "w20_fastwp_vc",
					"heading" 		=> esc_html__( "Stop Hour", 'gems' ),
					"param_name" 	=> "stop_hour",
					"value" 		=> range( 0, 23 ),
					"default"		=> "default",
					"admin_label"	=> true,
				),
				array(
					"save_always"   => true,
					"type" 			=> "dropdown",
					"holder"        => false,
					"edit_field_class"=> "w20_fastwp_vc",
					"heading" 		=> esc_html__("Stop Minute",'gems'),
					"param_name" 	=> "stop_minute",
					"value" 		=> range( 0, 59 ),
					"default"		=> "default",
					"admin_label"	=> true,
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Digits Color",'gems'),
					"param_name" 	=> 'digits_color',
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Default: #fff",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Text Color",'gems'),
					"param_name" 	=> 'text_color',
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Default: #898989",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Extra Class",'gems'),
					"param_name" 	=> 'extra_class',
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Use this options to add an extra class to element, you can use this for custom css",'gems')
				)
 			)
        );

	}

}

?>