<?php

class FastwpGemsFeatureBoxes extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;

		$fastwp_gems_shortcodes['fastwp_gems_feature_boxes_container'] = array( 'class' => __CLASS__, 'function' => 'shortcode_container' );
		$fastwp_gems_shortcodes['fastwp_gems_feature_boxes_item'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode_container( $atts, $content ) {
		extract( shortcode_atts( array(
			'layout'        => '',
            'columns'       => 3,
			'extra_class'   => ''
		), $atts ) );

		$class = array();

		if( !empty( $extra_class ) ) {
			$class[] = esc_attr( $extra_class );
		}

        self::set_vars( array( 'layout' => $layout, 'columns' => $columns ) );

		if( $layout == '1' ) {

            $markup = '<div class="row featureBoxes-3%s" data-equalizer data-equalize-on="medium">
                %s
            </div>';

			return sprintf( $markup, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), do_shortcode( $content ) );

		} else {

            $markup = '<div class="row featureBoxes-3%s" data-equalizer data-equalize-on="medium">
                %s
            </div>';

			return sprintf( $markup, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), do_shortcode( $content ) );

		}
	}

	public static function shortcode( $atts, $content ) {
		extract( shortcode_atts( array(
			'title'         => '',
            'background'    => '',
            'box_shadow'    => '',
			'content_lines' => '',
			'extra_class'   => ''
		), $atts ) );

		if( !empty( $extra_class ) ) {
		    $class[] = esc_attr( $extra_class );
		}

		$util_vars = self::get_vars();

        $column_size = array( 1 => 12, 2 => 6, 3 => 4, 4 => 3 );
        $columns = isset( $util_vars['columns'] ) && in_array( $util_vars['columns'], array_keys( $column_size ) ) ? $column_size[$util_vars['columns']] : 6;

        $text_lines = array();

        $lines = vc_param_group_parse_atts( $content_lines );

        if( !empty( $lines ) ) {
            foreach( $lines as $line ) {
                if( isset( $line['content_line'] ) )
                $text_lines[] = $line['content_line'];
            }
        }

        if( $util_vars['layout'] == 1 ) {

            $markup = '<div class="small-12 medium-12 large-%s columns%s">
                          <div class="featureBoxesWrapper %s%s" data-equalizer-watch>
                            <h5 class="featureBoxTitle">%s</h5>
                            <p>%s</p>
                          </div>
                        </div>';

            return sprintf( $markup, $columns, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), self::is_valid( 'colors', $background, 'bgGray' ), ( (boolean) $box_shadow ? ' boxShadow' : '' ), esc_html( $title ), implode( ' ', $text_lines ) );

        } else {

            $lines = '';
            foreach( $text_lines as $text_line ) {
                $lines .= '<li>' . esc_html( $text_line ) . '</li>';
            }

            $markup = '<div class="small-12 medium-12 large-%s columns%s">
                          <div class="featureBoxesWrapper %s%s" data-equalizer-watch>
                            <h5 class="featureBoxTitle">%s</h5>
                            <ul class="iconList">
                                %s
                            </ul>
                            </div>
                        </div>';

            return sprintf( $markup, $columns, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), self::is_valid( 'colors', $background, 'bgGray' ), ( (boolean) $box_shadow ? ' boxShadow' : '' ), esc_html( $title ), $lines );

        }
	}

	public static function vc_block(){
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Feature Boxes', 'gems' ),
			"base"      => 'fastwp_gems_feature_boxes_container',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"as_parent" => array('only' => 'fastwp_gems_feature_boxes_item'),
			"params"    => array(
				array(
					"save_always"  => true,
					"type"    => 'dropdown',
					"holder"   => false,
					"heading"   => esc_html__( "Layout", 'gems' ),
					"param_name"  => "layout",
					'value'   => array(
        			                    esc_html__( 'Layout 1', 'gems' )     => 1,
        					            esc_html__( 'Layout 2', 'gems' )     => 2
        					            ),
					"admin_label" => true
				),
				array(
					"save_always"  => true,
					"type"    => 'dropdown',
					"holder"   => false,
					"heading"   => esc_html__( "Items", 'gems' ),
					"param_name"  => "columns",
					'value'   => array(
                                        1   => 1,
        			                    2   => 2,
        					            3   => 3,
                                        4   => 4
        					            ),
					"admin_label" => true
				),
				array(
					"save_always"   => true,
					"group"         => 'Extra',
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Extra Class', 'gems' ),
					"param_name"    => 'extra_class',
					"admin_label"   => true,
					"description"   => esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				),
			 ),
			'js_view' => 'VcColumnView',
		);   

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"               => esc_html__( 'Feature Box', 'gems' ),
			"base"               => 'fastwp_gems_feature_boxes_item',
			"icon"               => get_template_directory_uri() . "/assets/img/logo-square.png",
			"as_child"           => array('only' => 'fastwp_gems_feature_boxes_container' ),
			"category"           => esc_html__( 'Gems Elements', 'gems' ),
			'content_element'    => true,
			"params"    => array(
				array(
					"save_always"   => true,
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Title', 'gems' ),
					"param_name"    => 'title',
					"admin_label"   => true
				),
				array(
                    'type'          => 'param_group',
                    'param_name'    => 'content_lines',
                    'params'        =>  array(
                            				array(
                            					"save_always"   => true,
                            					"type"          => 'textarea',
                            					"heading"       => esc_html__( 'Content', 'gems' ),
                            					"param_name"    => 'content_line',
                            					"admin_label"   => true
                            				),
                                        )
                ),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Text Box Background", 'gems' ),
					"param_name" 	=> "background",
					'value'			=> FastwpGemsShortcodeUtils::is_valid( 'colors', true, true ),
					"admin_label"	=> true
				),
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"holder"        => false,
					"heading"       => esc_html__( "Box Shadow", 'gems' ),
					"param_name"    => "box_shadow",
					'value'         => array(
        			                        esc_html__( 'Yes', 'gems' )  => 1,
        					                esc_html__( 'No', 'gems' )   => 0
        					                ),
					"admin_label"   => true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"heading" 		=> esc_html__( 'Extra Class', 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				)
			)
		);
	}
}

if ( class_exists( 'WPBakeryShortCodesContainer' ) ) { class WPBakeryShortCode_fastwp_gems_feature_boxes_container extends WPBakeryShortCodesContainer { } }
if ( class_exists( 'WPBakeryShortCode' ) ) { class WPBakeryShortCode_fastwp_gems_feature_boxes_item extends WPBakeryShortCode { } }

?>