<?php

class FastwpGemsHeroTitle extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_hero_title'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode( $atts, $content ) {
		extract(shortcode_atts(array(
            'title'         => 'Title',
            'background'    => '',
            'title_color'   => '',
            'lines_color'   => '',
            'show_lines'    => true,
            'bighero'       => false,
            'extra_class'   => ''
		), $atts));

        $class = array();

		$class[] = $title_id = 'fwp-heroTitle-' . rand( 1000, 9999 );

        if( !empty( $extra_class ) ) {
            $class[] = esc_attr( $extra_class );
        }

        $item_markup = '<div class="heroWrapper %s relPosition">

                        <div class="%s bgGray"%s>
                          <div class="horizontalCenter">
                            <div class="row">
                              <div class="small-11 medium-8 large-6 small-centered columns padding">

                                <div class="pageTitle">
                                  <span>%s</span>
                                </div>

                              </div>
                            </div>
                          </div>
                        </div>

                    </div>';

        if( !empty( $title_color ) ) {
            self::add_css( sprintf('.%s .pageTitle{color:%s;}', $title_id, esc_html( $title_color ) ) );
        }
        if( !empty( $lines_color ) && (boolean) $show_lines ) {
            self::add_css( sprintf('.%s .pageTitle::before,.%s .pageTitle::after{background:%s;}', $title_id, $title_id, esc_html( $lines_color ) ) );
        }

        $style = '';
        if( !empty( $background ) ) {
            if( filter_var( $background, FILTER_VALIDATE_URL ) ) {
                $image = esc_url( $background );
            } else {
                $attachment  = wp_get_attachment_image_src( $background, 'full' );
                $image = $attachment[0];
            }
            $style = sprintf( ' style="background-image: url(\'%s\'); background-position: %s %s;"', $image, '50%', '50%' );
        }

		return sprintf( $item_markup, implode( ' ', $class ), ( (boolean) $bighero ? 'hero' : 'heroSmall' ), $style, $title );
    }

	public static function vc_block(){
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Hero Title', 'gems' ),
			"base"      => 'fastwp_gems_hero_title',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"params"    => array(
				array(
					"save_always" 	=> true,
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( 'Title','gems' ),
					"param_name" 	=> 'title',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Hero section title', 'gems' )
				),
    			array(
					"save_always" 	=> true,
					"type" 			=> 'attach_image',
					"holder" 		=> false,
					"heading" 		=> esc_html__( 'Background', 'gems' ),
					"param_name" 	=> 'background',
					"admin_label"	=> true,
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__( 'Title Color', 'gems' ),
					"param_name" 	=> 'title_color',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Modify title color', 'gems' )
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( 'Show Lines', 'gems' ),
					"param_name" 	=> 'show_lines',
					'value'			=> array(
        							        esc_html__( 'Yes', 'gems' )  => 1,
        							        esc_html__( 'No', 'gems' )   => 0,
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Choose to show or hide the line/s. Default: Yes (visible)', 'gems' )
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( 'Big Image', 'gems' ),
					"param_name" 	=> 'bighero',
					'value'			=> array(
        							        esc_html__( 'No', 'gems' )  => 0,
        							        esc_html__( 'Yes', 'gems' ) => 1,
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__( 'Lines Color', 'gems' ),
					"param_name" 	=> 'lines_color',
					"value" 		=> '#151515',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Modify lines color', 'gems' ),
                    "dependency"    => array( 'element' => 'show_lines', 'value' => array( '1' ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( 'Extra Class', 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				)
 			)
        );

	}

}

?>