<?php

class FastwpGemsMap extends FastwpgemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;

		$fastwp_gems_shortcodes['fastwp_gems_map'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode( $atts, $content ) {
        global $fastwp_gems_custom_js, $fastwp_gems_data;
		extract( shortcode_atts(array(
			'center'		=> '44.434596,26.080533',
            'pins'          => '',
			'map_style'		=> 'fastwp',
			'map_zoom'		=> 8,
			'map_izoom'		=> 12,
            'locations_map' => true,
            'title_label'   => 'Locations',
            'subtitle_label'=> 'Our Locations',
            'extra_class'   => ''
		), $atts ) );

        $pins = vc_param_group_parse_atts( $pins );

        if( empty( $pins ) ) {
            return ;
        }

        $mapId = 'map' . rand( 1, 99999 );

        $pin_list = array();

        foreach( $pins as $pin ) {
            $marker_pos = explode( ',', $pin['marker_addr'] );
    		$fastwp_gems_custom_js[$mapId]['gmap_marker_title'][]  = $pin_title = esc_html( $pin['marker_title'] );
    		$fastwp_gems_custom_js[$mapId]['gmap_marker_addrs'][]  = $marker_lat_lng = array_map( 'trim', $marker_pos );
    		$fastwp_gems_custom_js[$mapId]['gmap_marker_ct'][]     = $pin['marker_content'];
            $fastwp_gems_custom_js[$mapId]['gmap_marker'][] = get_template_directory_uri() . '/assets/img/pin.svg';
            $pin_list[] = array( 'title' => $pin_title,
                                 'lat' => $marker_lat_lng[0],
                                 'lng' => $marker_lat_lng[1]
                                );
        }

		$map_center_pos = explode( ',', $center );
		$fastwp_gems_custom_js[$mapId]['gmap_center']     = $center_lat_lng = array_map( 'trim', $map_center_pos );
		$fastwp_gems_custom_js[$mapId]['gmap_style'] 		= $map_style;
		$fastwp_gems_custom_js[$mapId]['gmap_zoom'] 		= $map_zoom;
		$fastwp_gems_custom_js[$mapId]['gmap_izoom'] 		= $map_izoom;

		do_action( 'fastwp_gems_enqueue_script', 'custom,//maps.googleapis.com/maps/api/js?key=' . ( !empty( $fastwp_gems_data['fwp_gmap_key'] ) ? esc_html( $fastwp_gems_data['fwp_gmap_key'] ) : '' ) );

        $omap_markup = '<div class="map-container' . ( !empty( $extra_class ) ? ' ' . esc_attr( $extra_class ) : '' ) . '">
        <div class="fwp-map" data-mapId="' . $mapId . '"></div>
        </div>';

        if( (boolean) $locations_map ) {

        $pin_markup = '';
        foreach( $pin_list as $pin ) {
            $a_class = '';
            if( $pin['lat'] == $center_lat_lng[0] && $pin['lng'] == $center_lat_lng[1] ) {
                $a_class = ' active';
            }
            $pin_markup .= sprintf( '<li><a href="#" class="map-pan-link%s" data-lat="%s" data-lng="%s">%s</a></li>', $a_class, $pin['lat'], $pin['lng'], $pin['title'] );
        }

        $map_markup = sprintf( '<div class="row">

						<div class="column width-4">
							<h3 class="mb-50">%s</h3>
							<div class="map-pan-link-container">
								<h6>%s</h6>
								<ul>
									%s
								</ul>
							</div>
						</div>
						<div class="column width-8">
                            %s
                        </div>

                        </div>', esc_html( $title_label ), esc_html( $subtitle_label ), $pin_markup, $omap_markup );
        } else {
            $map_markup = $omap_markup;
        }

        return $map_markup;

	}

	public static function vc_block() {

		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
				"name"      => esc_html__( 'Google Map', 'gems' ),
				"base"      => 'fastwp_gems_map',
				"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
				"category"  => esc_html__( 'Gems Elements', 'gems' ),
				"params"    => array(
				array(
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__( 'Center of map', 'gems' ),
					"param_name"    => 'center',
					"value"         => '44.434596,26.080533',
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"type" 			=> "dropdown",
					"holder"        => false,
					"heading" 		=> esc_html__( 'Map style', 'gems' ),
					"param_name" 	=> "map_style",
					"value" 		=> array( 'FastwpStyle' => 'fastwp', 'Default Google Style' => 'default' ),
					"description" 	=> esc_html__( 'Choose map style', 'gems' ),
					"admin_label"   => true,
				),
				array(
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__( 'Default zoom', 'gems' ),
					"param_name"    => "map_zoom",
					"value"         => '8',
					"admin_label"   => true,
				),
				array(
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__( 'Zoom of map when click on a marker', 'gems' ),
					"param_name"    => "map_izoom",
					"value"         => '12',
					"admin_label"   => true
				),
				array(
                    'type'          => 'param_group',
                    'param_name'    => 'pins',
                    'params'        =>  array(
                            				array(
                            					"save_always"   => true,
                            					"type"          => 'textfield',
                            					"holder"        => false,
                            					"heading"       => esc_html__( 'Marker coordinates', 'gems' ),
                            					"param_name"    => 'marker_addr',
                            					"value"         => '44.434596,26.080533',
                            					"admin_label"   => false,
                            					//"description"   => esc_html__( '', 'gems' )
                            				),
                            				array(
                            					"save_always"   => true,
                            					"type"          => 'textfield',
                            					"holder"        => false,
                            					"heading"       => esc_html__( 'Marker title', 'gems' ),
                            					"param_name"    => 'marker_title',
                            					"value"         => 'Our Location',
                            					"admin_label"   => false,
                            					//"description"   => esc_html__( '', 'gems' )
                            				),
                            				array(
                            					"save_always"   => true,
                            					"type"          => 'textarea',
                            					"holder"        => false,
                            					"heading"       => esc_html__( 'Marker content', 'gems' ),
                            					"param_name"    => 'marker_content',
                            					"admin_label"   => false,
                            					//"description"   => esc_html__( '', 'gems' )
                            				)
                                        )
                ),
				array(
                    "group"         => esc_html__( 'Locations Container', 'gems' ),
					"save_always"   => true,
					"type" 			=> "dropdown",
					"holder"        => false,
					"heading" 		=> esc_html__( 'Show Locations Container', 'gems' ),
					"param_name" 	=> 'locations_map',
					"value" 		=> array( esc_html__( 'No', 'gems' ) => 0, esc_html__( 'Yes', 'gems' ) => 1 ),
					"description" 	=> esc_html__( 'Show or hide container locations', 'gems' ),
					"admin_label"   => true,
				),
				array(
                    "group"         => esc_html__( 'Locations Container', 'gems' ),
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__( 'Head Title', 'gems' ),
					"param_name"    => 'title_label',
					"value"         => 'Locations',
					"admin_label"   => true,
                    'dependency'    => array(
                                            'element'   => 'locations_map',
                                            'value'     => array( '1' )
                                            )
				),
				array(
                    "group"         => esc_html__( 'Locations Container', 'gems' ),
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__( 'Title', 'gems' ),
					"param_name"    => 'subtitle_label',
					"value"         => 'Our Locations',
					"admin_label"   => true,
                    'dependency'    => array(
                                            'element'   => 'locations_map',
                                            'value'     => array( '1' )
                                            )
				),
 				array(
                    "group"         => esc_html__( 'Extras', 'gems' ),
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__("Extra class", 'gems' ),
					"param_name"    => "extra_class",
					"admin_label"   => true
				),
			)
		);

    }

}

?>