<?php

class FastwpGemsPortfolio extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_portfolio'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode( $atts, $content ) {
		extract(shortcode_atts(array(
			'include'			=> '',
			'exclude'			=> '',
            'include_cats'		=> '',
            'exclude_cats'		=> '',
            'limit'             => -1,
	      	'cat_orderby' 	    => 'count',
		  	'hide_empty'	    => 1,
            'show_filters'      => true,
            'filters_pos'       => 1,
            'filters_transition'=> 0.7,
            'default_category'  => '*',
            'gutter'            => 5,
            'masonry'           => true,
            'columns'           => 3,
            'all_label'         => esc_html( 'All', 'gems' ),
            'cursor'            => '',
            'row_expanded'      => true,
            'items_padding'     => true,
            'margin_top'        => false,
            'margin_bottom'     => false,
            'extra_class'       => ''
		), $atts));

		$args = array(
			'numberposts' 		=> $limit,
			'posts_per_page' 	=> '-1',
			'post_status' 		=> 'publish',
			'post_type'			=> 'fwp_portfolio',
			'include'			=> $include,
			'exclude'			=> $exclude,
			'suppress_filters'	=> '0',
			);

		if( $include != '' ) {
			$args['include'] = $include;
            $args['orderby'] = 'post__in';
		}

		if( $exclude != '' ) {
			$args['exclude'] = $exclude;
		}

        if( !empty( $exclude_cats ) && empty( $include_cats ) ) {
        $args['tax_query'] = array(
          array(
            'taxonomy' => 'portfolio-category',
            'field'    => 'ids',
            'terms'    => ( $excluded_cats = explode( ',', $exclude_cats ) ),
            'operator' => 'NOT IN'
          )
        );
        }

        if( !empty( $include_cats )  ) {
        $args['tax_query'] = array(
          array(
            'taxonomy' => 'portfolio-category',
            'field'    => 'ids',
            'terms'    => explode( ',', $include_cats )
          )
        );
        }

        $items = get_posts( $args );

		if( !is_array( $items ) || ( is_array( $items ) && count( $items ) == 0 ) ) {
			return esc_html__( 'Used [Gems-Portfolio] shortcode but no portfolio items is selected. <br>Please add at least one portfolio item before using this shortcode.', 'gems' );
		}

        $cats = $isotope = $class = $cat_class = array();
        $top_filters    = (boolean) $show_filters && (int) $filters_pos === 1 ? true : false;
        $left_filters   = (boolean) $show_filters && (int) $filters_pos === 2 ? true : false;
        $cats['*']      = !empty( $all_label ) ? esc_html( $all_label ) : esc_html__( 'All', 'gems' );

		$class[] = $portfolio_id    = 'fwp-portfolio-' . rand( 1000, 9999 );

        if( $row_expanded ) {
            $class[] = 'expanded';
        }

        if( !empty( $margin_top ) ) {
            $class[] = 'marginTop';
        }

        if( !empty( $margin_bottom ) ) {
            $class[] = 'marginBottom';
        }

        if( !empty( $extra_class ) ) {
            $class[] = esc_attr( $extra_class );
        }

        if( empty( $items_padding ) ) {
            $cat_class[] = 'noPadding';
        }

        $items_markup = '';

		foreach( $items as $item ) {

            $meta               = FastwpGemsMeta::get( $item->ID );
    		$pitem_id           = 'fwp_gems_folio_item_' . rand( 1000, 9999 );
    		$title 	            = $item->post_title;
            $content            = $item->post_content;
    		$image 	            = wp_get_attachment_image_src( get_post_thumbnail_id( $item->ID ), 'full' );
            $item_cats          = array();
    		$item_terms         = wp_get_object_terms( $item->ID, 'portfolio-category' );
            $overlay_color      = isset( $meta['ptf_overlay_color'] ) ? esc_html( $meta['ptf_overlay_color'] ) : '';
            $overlay_opacity    = isset( $meta['ptf_overlay_opacity'] ) ? esc_html( $meta['ptf_overlay_opacity'] ) : 1;
            $title_color        = isset( $meta['ptf_title_color'] ) ? esc_html( $meta['ptf_title_color'] ) : '';
            $categories_color   = isset( $meta['ptf_categories_color'] ) ? esc_html( $meta['ptf_categories_color'] ) : '';

    		foreach( $item_terms as $item_cat ) {
        		if( isset( $excluded_cats ) && in_array( $item_cat->term_id, $excluded_cats ) ) continue;
        		$item_cats[$item_cat->slug] = $item_cat->name;
                $cats['.' . $item_cat->slug] = $item_cat->name;
    		}

            if( !empty( $overlay_color ) ) {
                self::add_css( sprintf('.%s:hover .imageHover{background-color:%s!important;}', $pitem_id, FastwpGemsUtils::hex2rgba( $overlay_color, $overlay_opacity ) ) );
            }
            if( !empty( $title_color ) ) {
                self::add_css( sprintf('.%s:hover .imageHover .itemDesc p{color:%s!important;}', $pitem_id, esc_html( $title_color ) ) );
            }
            if( !empty( $categories_color ) ) {
                self::add_css( sprintf('.%s:hover .imageHover .itemDesc span.smallText{color:%s!important;}', $pitem_id, esc_html( $categories_color ) ) );
            }

    		$items_markup .= sprintf( '<li class="gallery-item column %s">
                    <a href="%s" class="relPosition">
                      <img src="%s" alt="">
                      <div class="imageHover">
                        <div class="itemDesc">
                          <p>%s</p>
                          <span class="smallText">%s</span>
                        </div>
                      </div>
                    </a>
                  </li>', implode( ' ', array_merge( array( $pitem_id ), array_keys( $item_cats ) ) ), get_the_permalink( $item->ID ), $image[0], $title, implode( ' / ', array_values( $item_cats ) ) ); 

        }

        $default_category           = in_array( $default_category, array_keys( $cats ) ) ? $default_category : '*';

        $markup = sprintf( '<div class="row %s clearfix">', implode( ' ', $class ) );

        if( $left_filters ) {

            $markup .= '<div class="small-12 medium-3 large-2 columns">
            <div id="filters" class="folioNav-vertical">';
            foreach( $cats as $cat_filter => $cat_name ) {
                $markup .= sprintf( '<a data-filter="%s"%s>%s</a>', $cat_filter, ( $cat_filter == $default_category ? ' class="is-checked"' : '' ), $cat_name );
            }
            $markup .= '</div>
            </div>';

        }

        if( $top_filters ) {

            $markup .= '<div class="small-12 columns">
            <div id="filters" class="folioNav">';
            foreach( $cats as $cat_filter => $cat_name ) {
                $markup .= sprintf( '<a data-filter="%s"%s>%s</a>', $cat_filter, ( $cat_filter == $default_category ? ' class="is-checked"' : '' ), $cat_name );
            }
            $markup .= '</div>
            </div>';

        }

        $isotope['itemSelector']        = '.gallery-item';
        $isotope['filter']              = $default_category;
        $isotope['transitionDuration']  = (double) $filters_transition <= 1 && (double) $filters_transition >= 0 ? $filters_transition . 's' : '0.7s';
        if( (boolean) $masonry ) {
            $isotope['masonry']['gutter'] = 0;
        }

        $markup .= sprintf( '<div class="small-12 medium-%s large-%s columns%s noPadding">
          <div class="projectsWrapper">
          <ul id="gallery" class="row small-up-1 medium-up-2 large-up-%s %s portfolio portfolioGutter" data-fwp-isotope=\'%s\'>',
          ( $left_filters ? 9 : 12 ), ( $left_filters ? 10 : 12 ), ( !empty( $cat_class ) ? ' ' . implode( ' ', $cat_class ) : '' ), ( in_array( (int) $columns, array( 2, 3, 4 ) ) ? $columns : 3 ), ( (boolean) $masonry ? 'folioMasonry' : 'folioGrid' ), json_encode( $isotope ) );

        $markup .= $items_markup;

        $markup .= '</ul>
        </div>
        </div>

        </div>';

        // set new style to this portfolio
        if( is_numeric( $gutter ) && $gutter <= 20 ) {
            self::add_css( sprintf('.%s .gallery-item{padding:0 %spx %spx %spx!important;}', $portfolio_id, $gutter, $gutter*2, $gutter ) );
        }
        if( !empty( $cursor ) && in_array( $cursor, array( 'initial', 'zoom-in', 'pointer' ) ) ) {
            self::add_css( sprintf('.%s .gallery-item .imageHover{cursor:%s!important;}', $portfolio_id, $cursor ) );
        }

        return $markup;
    }

	public static function vc_block() {
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Portfolio', 'gems' ),
			"base"      => 'fastwp_gems_portfolio',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"params"    => array(
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Masonry", 'gems' ),
					"param_name" 	=> 'masonry',
					'value'			=> array(
        							        esc_html__( 'Yes', 'gems' )   => 1,
        							        esc_html__( 'No', 'gems' )    => 0,
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Masonry or grid display", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Default Category", 'gems' ),
					"param_name" 	=> 'default_category',
					'value'			=> fastwp_gems_get_categories(),
					"default" 		=> '*',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Available when filters are visible.", 'gems' ),
                    "dependency"    => array( "element" => "show_filters", "value" => array( "1" ) )
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Items Per Row / Columns", 'gems' ),
					"param_name" 	=> 'columns',
					"value" 		=> '3',
					"default" 		=> '3',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Display 2, 3 or 4 images per row.", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "'All' Label", 'gems' ),
					"param_name" 	=> 'all_label',
					"default" 		=> 'All',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Field to custom display 'All' categories.", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Include/Exclude', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Include Projects", 'gems' ),
					"param_name" 	=> 'include',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Put project IDs to include only these", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Include/Exclude', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Exclude Projects", 'gems' ),
					"param_name" 	=> 'exclude',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Put project IDs to exclude only these", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Include/Exclude', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Include Portfolio Categories", 'gems' ),
					"param_name" 	=> 'include_cats',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Put category IDs to include only these", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Include/Exclude', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Exclude Portfolio Categories", 'gems' ),
					"param_name" 	=> 'exclude_cats',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Put category IDs to exclude only these", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Filters', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Show Filters",'gems'),
					"param_name" 	=> 'show_filters',
					'value'			=> array(
        							        esc_html__( 'Yes', 'gems' )   => 1,
        							        esc_html__( 'No', 'gems' )    => 0,
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose to show or hide the filters.",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Cursor",'gems'),
					"param_name" 	=> 'cursor',
					'value'			=> array(
        							        'Default/Image' => '',
        							        'Initial'       => 'initial',
        							        'Pointer'       => 'pointer',
        							        'Zoom-In'       => 'zoom-in',
        							    	),
					"default" 		=> '',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Gutter",'gems' ),
					"param_name" 	=> 'gutter',
					"default" 		=> '5',
					"admin_label"	=> true,
					"description"	=> esc_html__( "In pixels, only numbers.",'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Row Expaned", 'gems' ),
					"param_name" 	=> 'row_expanded',
					'value'			=> array(
        							        esc_html__( 'Yes', 'gems' )   => 1,
        							        esc_html__( 'No', 'gems' )    => 0,
        							    	),
					"default" 		=> '0',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Display full row", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Items Column Padding", 'gems' ),
					"param_name" 	=> 'items_padding',
					'value'			=> array(
        							        esc_html__( 'Yes', 'gems' )   => 1,
        							        esc_html__( 'No', 'gems' )    => 0,
        							    	),
					"default" 		=> '0',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Use or not padding for items container", 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Margin Top", 'gems' ),
					"param_name" 	=> 'margin_top',
					'value'			=> array(
        							        esc_html__( 'No', 'gems' )    => 0,
        							        esc_html__( 'Yes', 'gems' )   => 1
        							    	),
					"default" 		=> '0',
					"admin_label"	=> true,
                    "edit_field_class"=> "w50_fastwp_vc"
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Margin Bottom", 'gems' ),
					"param_name" 	=> 'margin_bottom',
					'value'			=> array(
        							        esc_html__( 'No', 'gems' )    => 0,
        							        esc_html__( 'Yes', 'gems' )   => 1
        							    	),
					"default" 		=> '0',
					"admin_label"	=> true,
                    "edit_field_class"=> "w50_fastwp_vc"
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Filters', 'gems' ),
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Filters Possition",'gems'),
					"param_name" 	=> 'filters_pos',
					'value'			=> array(
        							        esc_html__( 'Top', 'gems' )   => 1,
        							        esc_html__( 'Left', 'gems' )    => 2,
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose the possition of the filters.'",'gems'),
                    "dependency"    => array( "element" => "show_filters", "value" => array( "1" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Filters', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Filters Transition",'gems'),
					"param_name" 	=> 'filters_transition',
					"default" 		=> '0.7',
                    "value"         => 0.7,
					"admin_label"	=> true,
					"description"	=> esc_html__("Filters transition duration, in 'double' format. Default: 0.7'",'gems'),
                    "dependency"    => array( "element" => "show_filters", "value" => array( "1" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Extra Class",'gems'),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__("Use this options to add an extra class to element, you can use this for custom css",'gems')
				)
 			)
        );

	}

}

?>