<?php

class FastwpGemsPrices extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_prices'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode( $atts, $content ) {
        global $fastwp_gems_data;
        extract( shortcode_atts( array(
            'default_category'  => 0,
            'columns'           => 3,
            'include'           => '',
            'exclude'           => '',
            'include_cats'      => '',
            'exclude_cats'      => '',
            'extra_class'	    => ''
        ), $atts ) );

        $class = array();

        if( !empty( $extra_class ) ) {
            $class[] = esc_attr( $extra_class );
        }

        // The Query

        $cat_query = array();

		$query  = array(
                        'post_type'         => 'fwp_menu',
                        "posts_per_page"    => -1,
            			'numberposts'       => -1,
            			'suppress_filters'  => true
                        );

		if( $include != '' ) {
			$query['post__in'] = explode( ',', $include );
            $query['orderby'] = 'post__in';
		}

		if( $exclude != '' ) {
			$query['post__not_in'] = explode( ',', $exclude );
		}

        if( !empty( $exclude_cats ) && empty( $include_cats ) ) {
            $query['tax_query'] = array(
                array(
                    'taxonomy' => 'menu-category',
                    'field'    => 'ids',
                    'terms'    => array_filter( explode( ',', $exclude_cats ) ),
                    'operator' => 'NOT IN'
                )
            );
            $cat_query['exclude'] = $exclude_cats;
        }

        if( !empty( $include_cats )  ) {
            $query['tax_query'] = array(
                array(
                    'taxonomy' => 'menu-category',
                    'field'    => 'ids',
                    'terms'    => array_filter( explode( ',', $include_cats ) )
                )
            );
            $cat_query['include'] = $include_cats;
        }

        $the_query  = new WP_Query( $query );

        $markup     = $filters_markup = '';
        $columns2   = array( 1 => 12, 2 => 6, 3 => 4, 4 => 3 );
        $filters    = fastwp_gems_get_category_list_array( $cat_query, 'menu-category' );
        $the_id     = rand( 100,999 );
        $def_cat    = get_term( $default_category, 'menu-category' );
        $column     = in_array( $columns, array_keys( $columns2 ) ) ? $columns : 3;

        if( !empty( $filters ) ) {
            $filters_markup = '<div id="filters-' . $the_id . '" class="folioNav noPadding">';

            foreach( $filters as $filter => $name ) {
                $filters_markup .= '<a data-filter=".' . $filter . '" class="link' . ( isset( $def_cat->slug ) && $def_cat->slug == $filter ? ' is-checked' : '' ) . '">' . $name . '</a>';
            }

            $filters_markup .= '</div>';
        }

        $markup .= $filters_markup;

        $markup .= '<div class="row menu-' . $the_id . '">';

        if ( $the_query->have_posts() ) {
        	while ( $the_query->have_posts() ) {

                $the_query->the_post();
                $cats = fastwp_gems_get_post_category_list_array( 'menu-category' );

                $markup .= '<div class="menuItem' . ( !empty( $cats ) ? ' ' . implode( ' ', array_keys( $cats ) ) : '' ) . ' small-12 medium-6 large-' . $columns2[$column] . ' columns">
                  <span>' .  get_the_title() . '</span>
                  <p class="smallText">' . get_the_content() . '</p>
                </div>';

            }
            wp_reset_postdata();
        }

        $markup .= '</div>';

        ?>

        <script>
        (function($) {
            jQuery(window).on('load', function() {

              var $container = $('.menu-<?php echo (int) $the_id; ?>');

              $container.isotope({
                  itemSelector: '.menuItem',
                  filter: '<?php echo ( isset( $def_cat->slug ) ? '.' . $def_cat->slug : '*' ); ?>'
              });

              // filter items on button click
              $('#filters-<?php echo (int) $the_id; ?>').on('click', 'a', function () {
                  var filterValue = $(this).attr('data-filter');
                  $container.isotope({ filter: filterValue });
              });

              // change is-checked class on buttons
              $('#filters-<?php echo (int) $the_id; ?> a').on('click', function() {
                  $('#filters-<?php echo (int) $the_id; ?> a').removeClass('is-checked');
                  $(this).addClass('is-checked');
                  var selector = $(this).attr('data-filter');
                  $container.isotope({ filter: selector });
                  return false;
              });

              $(window).on('resize', function() {
                  $container.isotope('layout');
              });

              Foundation.reInit('equalizer');

            });
        })(jQuery);
        </script>

        <?php

        do_action( 'fastwp_gems_enqueue_script', 'libr/Isotope' );

        return $markup;
    }

	public static function vc_block() {
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Menus Prices', 'gems' ),
			"base"      => 'fastwp_gems_prices',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"params"    => array(
                array(
                    "save_always"   => true,
                    "type"          => 'dropdown',
                    "holder"        => false,
                    "heading"       => esc_html__( "Default Category", 'gems' ),
                    "param_name"    => 'default_category',
                    "value"         => fastwp_gems_get_categories( false, 'menu-category' ),
                    "admin_label"   => true
                ),
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"heading"       => esc_html__( "Columns", 'gems' ),
					"param_name"    => "columns",
					'value'         => array( 3 => 3, 1 => 1, 2 => 2, 4 => 4 ),
					"admin_label"   => true
				),
        		array(
        			"save_always" 	=> true,
                    "group"         => esc_html__( 'Include/Exclude', 'gems' ),
        			"type" 			=> 'textfield',
        			"holder" 		=> false,
        			"heading" 		=> esc_html__( "Include just those items", 'gems' ),
        			"param_name" 	=> 'include',
        			"admin_label"	=> true,
        			"description"	=> esc_html__( "Use this option to include just selected gallery items to shortcode output", 'gems' )
        		),
        		array(
        			"save_always" 	=> true,
                    "group"         => esc_html__( 'Include/Exclude', 'gems' ),
        			"type" 			=> 'textfield',
        			"holder" 		=> false,
        			"heading" 		=> esc_html__( "Exclude those items", 'gems' ),
        			"param_name" 	=> 'exclude',
        			"admin_label"	=> true,
        			"description"	=> esc_html__( "Use this option to exclude selected gallery items from shortcode output", 'gems' )
        		),
                array(
                    "save_always"   => true,
                    "group"         => esc_html__( 'Include/Exclude', 'gems' ),
                    "type"          => 'checkbox',
                    "holder"        => false,
                    "heading"       => esc_html__( "Include Menu Prices Categories", 'gems' ),
                    "param_name"    => 'include_cats',
                    "value"         => fastwp_gems_get_categories( false, 'menu-category' ),
                    "admin_label"   => true,
                    "description"   => esc_html__( "Put menu prices IDs to include only these", 'gems' )
                ),
                array(
                    "save_always"   => true,
                    "group"         => esc_html__( 'Include/Exclude', 'gems' ),
                    "type"          => 'checkbox',
                    "holder"        => false,
                    "heading"       => esc_html__( "Exclude Menu Prices Categories", 'gems' ),
                    "param_name"    => 'exclude_cats',
                    "value"         => fastwp_gems_get_categories( false, 'menu-category' ),
                    "admin_label"   => true,
                    "description"   => esc_html__( "Put menu prices IDs to exclude only these", 'gems' )
                ),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"heading" 		=> esc_html__( 'Extra Class', 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				)
 			)
        );

	}

}

?>