<?php

class FastwpGemsServices extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;

		$fastwp_gems_shortcodes['fastwp_gems_services_container'] = array( 'class' => __CLASS__, 'function' => 'shortcode_container' );
		$fastwp_gems_shortcodes['fastwp_gems_services_item'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode_container( $atts, $content ) {
		extract( shortcode_atts( array(
			'layout'        => '',
            'columns'       => 3,
			'extra_class'   => ''
		), $atts ) );

		$class = array();

		if( !empty( $extra_class ) ) {
			$class[] = esc_attr( $extra_class );
		}

        self::set_vars( array( 'layout' => $layout, 'columns' => $columns ) );

		if( $layout == '1' ) {

            $markup = '<div class="row featureBoxes-1%s">
                %s
            </div>';

			return sprintf( $markup, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), do_shortcode( $content ) );

		} else {

			$markup = '<div class="row paddingTop featureBoxes-2%s">
                %s
            </div>';

			return sprintf( $markup, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), do_shortcode( $content ) );

		}
	}

	public static function shortcode( $atts, $content ) {
		extract( shortcode_atts( array(
			'title'         => '',
			'icon'          => '',
			'extra_class'   => ''
		), $atts ) );

		if( !empty( $extra_class ) ) {
		    $class[] = esc_attr( $extra_class );
		}

		$util_vars = self::get_vars();

        $column_size = array( 1 => 12, 2 => 6, 3 => 4, 4 => 3 );
        $columns = isset( $util_vars['columns'] ) && in_array( $util_vars['columns'], array_keys( $column_size ) ) ? $column_size[$util_vars['columns']] : 6;

        if( $util_vars['layout'] == 1 ) {

            $markup = '<div class="small-12 medium-%s columns%s">
                        <span class="%s"></span>
                        <h5 class="featureBoxTitle">%s</h5>
                        <p class="smallText">%s</p>
                    </div>';

            return sprintf( $markup, $columns, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), esc_html( $icon ), esc_html( $title ), $content );

        } else {

            $markup = '<div class="small-12 medium-%s columns%s">
                        <h5 class="featureBoxTitle">%s</h5>
                        <div class="boxIcon-2"><span class="%s"></span></div>
                        <p class="smallText">%s</p>
                    </div>';

            return sprintf( $markup, $columns, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), esc_html( $title ), esc_html( $icon ), $content );

        }
	}

	public static function vc_block(){
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Services', 'gems' ),
			"base"      => 'fastwp_gems_services_container',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"as_parent" => array('only' => 'fastwp_gems_services_item'),
			"params"    => array(
				array(
					"save_always"  => true,
					"type"    => 'dropdown',
					"holder"   => false,
					"heading"   => esc_html__( "Layout", 'gems' ),
					"param_name"  => "layout",
					'value'   => array(
        			                    esc_html__( 'Layout 1', 'gems' )     => 1,
        					            esc_html__( 'Layout 2', 'gems' )     => 2
        					            ),
					"admin_label" => true
				),
				array(
					"save_always"  => true,
					"type"    => 'dropdown',
					"holder"   => false,
					"heading"   => esc_html__( "Items", 'gems' ),
					"param_name"  => "columns",
					'value'   => array(
                                        1   => 1,
        			                    2   => 2,
        					            3   => 3,
                                        4   => 4
        					            ),
					"admin_label" => true
				),
				array(
					"save_always"   => true,
					"group"         => 'Extra',
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Extra Class', 'gems' ),
					"param_name"    => 'extra_class',
					"admin_label"   => true,
					"description"   => esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				),
			 ),
			'js_view' => 'VcColumnView',
		);   

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"               => esc_html__( 'Service Item', 'gems' ),
			"base"               => 'fastwp_gems_services_item',
			"icon"               => get_template_directory_uri() . "/assets/img/logo-square.png",
			"as_child"           => array('only' => 'fastwp_gems_services_container' ),
			"category"           => esc_html__( 'Gems Elements', 'gems' ),
			'content_element'    => true,
			"params"    => array(
				array(
					"save_always"   => true,
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Title', 'gems' ),
					"param_name"    => 'title',
					"admin_label"   => true
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'iconpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__( 'Icon', 'gems' ),
		            'param_name'    => 'icon',
					"admin_label"	=> true,
		            'settings'      => array(
            		                        'emptyIcon'    => true,
                                            'type'         => 'icomoon',
            		                        'iconsPerPage' => 200
        		                            ),
		             "description" 	=> esc_html__( 'Choose what icon do you want to use (icomoon icons).', 'gems' )
				),
				array(
					"save_always"   => true,
					'type'          => 'textarea',
					'heading'       => esc_html__( 'Content', 'gems' ),
					'param_name'    => 'content',
					"admin_label"   => true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"heading" 		=> esc_html__( 'Extra Class', 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				)
			)
		);
	}
}

if ( class_exists( 'WPBakeryShortCodesContainer' ) ) { class WPBakeryShortCode_fastwp_gems_services_container extends WPBakeryShortCodesContainer { } }
if ( class_exists( 'WPBakeryShortCode' ) ) { class WPBakeryShortCode_fastwp_gems_services_item extends WPBakeryShortCode { } }

?>