<?php

class FastwpGemsSwiperSlider extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_swiper_slider_container'] = array( 'class' => __CLASS__, 'function' => 'shortcode_container' );
		$fastwp_gems_shortcodes['fastwp_gems_swiper_slider_item'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode_container( $atts, $content ) {
		extract(shortcode_atts(array(
            'next_prev'     => true,
            'bullets'       => true,
			'extra_class'	=> ''
		), $atts));

		$markup = '<div class="swiper-container%s">
        <div class="swiper-wrapper">
            %s
        </div>';

        if( (boolean) $bullets ) {
            $markup .= '<div class="swiper-pagination"></div>';
        }

        if( (boolean) $next_prev ) {
            $markup .= '<div class="swiper-button-next swiper-button-black"></div>
            <div class="swiper-button-prev swiper-button-black"></div>';
        }

        $markup .= '</div>';

        return sprintf( $markup, ( !empty( $extra_class ) ? ' ' . sanitize_html_class( $extra_class ) : '' ), do_shortcode( $content ) );
    }

	public static function shortcode( $atts, $content ) {
		extract(shortcode_atts(array(
            'image'         => '',
            'visibility'    => true,
            'extra_class'   => ''
		), $atts));

        if( ! (boolean) $visibility ) return '';

        $item_markup = '<div class="swiper-slide%s">
                          <img src="%s" alt="" />
                        </div>';

        $image = wp_get_attachment_image_src( $image, 'full' );

		return sprintf( $item_markup, ( !empty( $extra_class ) ? ' ' . sanitize_html_class( $extra_class ) : '' ), $image[0] );
    }

	public static function vc_block(){
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			'name'                      => esc_html__( 'Swiper Slider', 'gems' ),
			'base'                      => 'fastwp_gems_swiper_slider_container',
			"icon"                      => get_template_directory_uri() . "/assets/img/logo-square.png",
			'as_parent'                 => array('only' => 'fastwp_gems_swiper_slider_item'),
            'category'                  => esc_html__('Gems Elements', 'gems'),
			'content_element'           => true,
			'show_settings_on_create'   => false,
			"params"                    => array(
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Next Preview Buttons", 'gems' ),
					"param_name" 	=> "next_prev",
					'value'			=> array(
        							        esc_html__( 'Visible', 'gems' )  => 1,
        						            esc_html__( 'Hidden', 'gems' )   => 0
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Bullets Navigation", 'gems' ),
					"param_name" 	=> "bullets",
					'value'			=> array(
        							        esc_html__( 'Visible', 'gems' )  => 1,
        						            esc_html__( 'Hidden', 'gems' )   => 0
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Slides", 'gems' ),
					"param_name" 	=> "slides",
					'value'			=> array(
        							        '1' => 1,
        						            '2' => 2,
                                            '3' => 3,
                                            '4' => 4,
                                            '5' => 5
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Extra Class", 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__("Use this options to add an extra class to element, you can use this for custom css",'gems')
				)
		    ),
			'js_view' => 'VcColumnView'
		);

		$fastwp_gems_visual_composer_blocks[] = array(
 			'name'              => esc_html( 'Swiper Slider Item', 'gems' ),
			'base'              => 'fastwp_gems_swiper_slider_item',
			"icon"              => get_template_directory_uri() . "/assets/img/logo-square.png",
			'as_child'          => array('only' => 'fastwp_gems_swiper_slider_container' ),
            'category'          => esc_html__('Gems Elements', 'gems'),
			'content_element'   => true,
			'params'            => array(
    			array(
					"save_always" 	=> true,
					"type" 			=> 'attach_image',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Slide Image", 'gems' ),
					"param_name" 	=> 'image',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Visibility", 'gems' ),
					"param_name" 	=> "visibility",
					'value'			=> array(
        							        esc_html__( 'Visible', 'gems' )  => 1,
        						            esc_html__( 'Hidden', 'gems' )   => 0
							    	        ),
					"default" 		=> '1',
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Extra Class",'gems'),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__("Use this options to add an extra class to element, you can use this for custom css",'gems')
				)
			)
		);
	}

}

if ( class_exists( 'WPBakeryShortCodesContainer' ) ) { class WPBakeryShortCode_fastwp_gems_swiper_slider_container extends WPBakeryShortCodesContainer { } }
if ( class_exists( 'WPBakeryShortCode' ) ) { class WPBakeryShortCode_fastwp_gems_swiper_slider_item extends WPBakeryShortCode { } }

?>