<?php

class FastwpGemsTeam extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;

		$fastwp_gems_shortcodes['fastwp_gems_team_container'] = array( 'class' => __CLASS__, 'function' => 'shortcode_container' );
		$fastwp_gems_shortcodes['fastwp_gems_team_item'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode_container( $atts, $content ) {
		extract( shortcode_atts( array(
            'columns'       => 3,
			'extra_class'   => ''
		), $atts ) );

		$class = array();

		if( !empty( $extra_class ) ) {
			$class[] = esc_attr( $extra_class );
		}

        self::set_vars( array( 'columns' => $columns ) );

        $markup = '<div class="row%s">
            %s
        </div>';

        return sprintf( $markup, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), do_shortcode( $content ) );
	}

	public static function shortcode( $atts, $content ) {
		extract( shortcode_atts( array(
			'name'          => '',
            'role'          => '',
			'icon'          => '',
            'image'         => '',
            'links'         => '',
            'background'    => '',        
			'extra_class'   => ''
		), $atts ) );

		if( !empty( $extra_class ) ) {
		    $class[] = esc_attr( $extra_class );
		}

		$util_vars = self::get_vars();

        $column_size = array( 2 => 6, 3 => 4, 4 => 3 );
        $columns = isset( $util_vars['columns'] ) && in_array( $util_vars['columns'], array_keys( $column_size ) ) ? $column_size[$util_vars['columns']] : 6;

        $image  = wp_get_attachment_image_src( $image, 'full' );

        $social_links = '';

        $links = vc_param_group_parse_atts( $links );

        if( !empty( $links ) ) {
            foreach( $links as $link ) {
                if( isset( $link['url'] ) && isset( $link['icon'] ) )
                $social_links .= sprintf( '<a href="%s"><span class="%s"></span></a>', esc_url( $link['url'] ), esc_html( $link['icon'] ) );
            }
        }

        $markup = '<div class="small-12 medium-%s columns%s">
                      <div class="teamMembers">
                        <div>
                          <img src="%s" alt="" />
                        </div>

                        <div class="teamContent %s">
                          <h6 class="teamName">%s</h6>
                          <p class="smallText">%s</p>
                          <div class="teamSocialIcons">
                            %s
                          </div>
                        </div>
                      </div>
                    </div>';

        return sprintf( $markup, $columns, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), $image[0], self::is_valid( 'colors', $background, 'bgGray' ), esc_html( $name ), esc_html( $role ), $social_links );

	}

	public static function vc_block(){
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Team', 'gems' ),
			"base"      => 'fastwp_gems_team_container',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"as_parent" => array('only' => 'fastwp_gems_team_item'),
			"params"    => array(
				array(
					"save_always"  => true,
					"type"    => 'dropdown',
					"holder"   => false,
					"heading"   => esc_html__( "Items", 'gems' ),
					"param_name"  => "columns",
					'value'   => array(
        			                    2   => 2,
        					            3   => 3,
                                        4   => 4
        					            ),
					"admin_label" => true
				),
				array(
					"save_always"   => true,
					"group"         => 'Extra',
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Extra Class', 'gems' ),
					"param_name"    => 'extra_class',
					"admin_label"   => true,
					"description"   => esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				),
			 ),
			'js_view' => 'VcColumnView',
		);

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"               => esc_html__( 'Team Member', 'gems' ),
			"base"               => 'fastwp_gems_team_item',
			"icon"               => get_template_directory_uri() . "/assets/img/logo-square.png",
			"as_child"           => array('only' => 'fastwp_gems_team_container' ),
			"category"           => esc_html__( 'Gems Elements', 'gems' ),
			'content_element'    => true,
			"params"    => array(
				array(
					"save_always"   => true,
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Name', 'gems' ),
					"param_name"    => 'name',
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Role', 'gems' ),
					"param_name"    => 'role',
					"admin_label"   => true
				),
    			array(
					"save_always" 	=> true,
					"type" 			=> 'attach_image',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Image",'gems' ),
					"param_name" 	=> 'image',
					"admin_label"	=> true
				),
				array(
                    'type'          => 'param_group',
                    'param_name'    => 'links',
                    'params'        =>  array(
                            				array(
                            					"save_always" 	=> true,
                            					"type" 			=> 'iconpicker',
                            					"holder" 		=> false,
                            					"heading" 		=> esc_html__( 'Icon', 'gems' ),
                            		            'param_name'    => 'icon',
                            					"admin_label"	=> true,         
                            		            'settings'      => array(
                                        		                        'emptyIcon'    => true,
                                                                        'type'         => 'icomoon',
                                        		                        'iconsPerPage' => 200
                                    		                            ),
                            		             "description" 	=> esc_html__( 'Choose what icon do you want to use (icomoon icons).', 'gems' )
                            				),
                            				array(
                            					"save_always"   => true,
                            					"type"          => 'textfield',
                            					"heading"       => esc_html__( 'URL', 'gems' ),
                            					"param_name"    => 'url',
                            					"admin_label"   => true
                            				),
                                        )
                ),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Text Box Background", 'gems' ),
					"param_name" 	=> "background",
					'value'			=> FastwpGemsShortcodeUtils::is_valid( 'colors', true, true ),
					"admin_label"	=> true
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"heading" 		=> esc_html__( 'Extra Class', 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				)
			)
		);
	}
}

if ( class_exists( 'WPBakeryShortCodesContainer' ) ) { class WPBakeryShortCode_fastwp_gems_team_container extends WPBakeryShortCodesContainer { } }
if ( class_exists( 'WPBakeryShortCode' ) ) { class WPBakeryShortCode_fastwp_gems_team_item extends WPBakeryShortCode { } }

?>