<?php

class FastwpGemsTestimonials extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;

		$fastwp_gems_shortcodes['fastwp_gems_testimonials_container'] = array( 'class' => __CLASS__, 'function' => 'shortcode_container' );
		$fastwp_gems_shortcodes['fastwp_gems_testimonials_item'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode_container( $atts, $content ) {
		extract( shortcode_atts( array(
			'layout'        => '',
            'columns'       => 3,
			'extra_class'   => ''
		), $atts ) );

		$class = array();

		if( !empty( $extra_class ) ) {
			$class[] = esc_attr( $extra_class );
		}

        self::set_vars( array( 'layout' => $layout, 'columns' => $columns ) );

		if( $layout == '1' ) {

            $markup = '<div class="row%s">
                %s
            </div>';

			return sprintf( $markup, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), do_shortcode( $content ) );

		} else {

            $markup = '<div class="orbit testimonialScroller%s" role="region" aria-label="Testimonials Scroller" data-orbit>
                <button class="icon-arrow-left orbit-previous"><span class="show-for-sr">Previous Slide</span></button>
                <button class="icon-arrow-right orbit-next"><span class="show-for-sr">Next Slide</span></button>

                <ul class="orbit-container">
                    %s
                </ul>
                </div>';

			return sprintf( $markup, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), do_shortcode( $content ) );

		}
	}

	public static function shortcode( $atts, $content ) {
		extract( shortcode_atts( array(
			'name'          => '',
            'role'          => '',
            'image'         => '',
            'image_effect'  => '',
			'extra_class'   => ''
		), $atts ) );

		if( !empty( $extra_class ) ) {
		    $class[] = esc_attr( $extra_class );
		}

		$util_vars = self::get_vars();

        if( $util_vars['layout'] == 1 ) {

            $column_size = array( 1 => 12, 2 => 6, 3 => 4, 4 => 3 );
            $columns = isset( $util_vars['columns'] ) && in_array( $util_vars['columns'], array_keys( $column_size ) ) ? $column_size[$util_vars['columns']] : 6;

            $markup = '<div class="small-12 medium-%s columns%s">
                  <div class="testimonial-1">
                    <div class="testimonImg %s">
                      <img src="%s" alt="" />
                    </div>
                    <div class="testimonMeta">
                        %s
                      <span>%s</span>
                    </div>
                    <div class="testimonContent">
                      <p>%s</p>
                    </div>
                  </div>
                </div>';

            $image  = wp_get_attachment_image_src( $image, 'full' );

            return sprintf( $markup, $columns, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), ( in_array( $image_effect, array( 'imgBorder', 'boxShadow' ) ) ? $image_effect : 'imgBorder' ), $image[0], esc_html( $name ), esc_html( $role ), esc_html( $content ) );

        } else {

            $markup = '<li class="orbit-slide%s">
                        <div class="testimonial-2">
                          <div class="testimonContent">
                            <p>%s</p>
                          </div>
                          <div class="testimonMeta">
                              %s
                            <span>%s</span>
                          </div>
                        </div>
                      </li>';

            return sprintf( $markup, ( !empty( $class ) ? ' ' . implode( ' ', $class ) : '' ), esc_html( $content ), esc_html( $name ), esc_html( $role ) );

        }
	}

	public static function vc_block(){
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Testimonials', 'gems' ),
			"base"      => 'fastwp_gems_testimonials_container',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"as_parent" => array('only' => 'fastwp_gems_testimonials_item'),
			"params"    => array(
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"holder"        => false,
					"heading"       => esc_html__( "Layout", 'gems' ),
					"param_name"    => "layout",
					'value'         => array(
        			                    esc_html__( 'Boxes', 'gems' )    => 1,
        					            esc_html__( 'Slider', 'gems' )   => 0
        			                    ),
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"holder"        => false,
					"heading"       => esc_html__( "Items", 'gems' ),
					"param_name"    => "columns",
					'value'         => array(
                                        1   => 1,
        			                    2   => 2,
        					            3   => 3,
                                        4   => 4
        					            ),
					"admin_label"   => true,
                    "dependency"    => array( "element" => "layout", "value" => array( "1" ) )
				),
				array(
					"save_always"   => true,
					"group"         => 'Extra',
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Extra Class', 'gems' ),
					"param_name"    => 'extra_class',
					"admin_label"   => true,
					"description"   => esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				),
			 ),
			'js_view' => 'VcColumnView',
		);   

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"               => esc_html__( 'Testimonial', 'gems' ),
			"base"               => 'fastwp_gems_testimonials_item',
			"icon"               => get_template_directory_uri() . "/assets/img/logo-square.png",
			"as_child"           => array('only' => 'fastwp_gems_testimonials_container' ),
			"category"           => esc_html__( 'Gems Elements', 'gems' ),
			'content_element'    => true,
			"params"    => array(
				array(
					"save_always"   => true,
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Name', 'gems' ),
					"param_name"    => 'name',
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Role', 'gems' ),
					"param_name"    => 'role',
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"type"          => 'textarea',
					"heading"       => esc_html__( 'Text', 'gems' ),
					"param_name"    => 'content',
					"admin_label"   => true
				),
    			array(
					"save_always" 	=> true,
					"type" 			=> 'attach_image',
					"holder" 		=> false,
					"heading" 		=> esc_html__( 'Image', 'gems' ),
					"param_name" 	=> 'image',
					"admin_label"	=> true,
                    'description'   => esc_html__( 'Used for Boxes only', 'gems' )
				),
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"holder"        => false,
					"heading"       => esc_html__( "Image Effect", 'gems' ),
					"param_name"    => "image_effect",
					'value'         => array(
        			                        esc_html__( 'Shadow', 'gems' )   => 'boxShadow',
        					                esc_html__( 'Border', 'gems' )   => 'imgBorder'
        					                ),
					"admin_label"   => true,
                    'description'   => esc_html__( 'Used for Boxes only', 'gems' )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"heading" 		=> esc_html__( 'Extra Class', 'gems' ),
					"param_name" 	=> 'extra_class',
					"admin_label"	=> true,
					"description"	=> esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'gems' )
				)
			)
		);
	}
}

if ( class_exists( 'WPBakeryShortCodesContainer' ) ) { class WPBakeryShortCode_fastwp_gems_testimonials_container extends WPBakeryShortCodesContainer { } }
if ( class_exists( 'WPBakeryShortCode' ) ) { class WPBakeryShortCode_fastwp_gems_testimonials_item extends WPBakeryShortCode { } }

?>