<?php

class FastwpGemsTitle extends FastwpGemsShortcodeUtils {

	function __construct() {
		global $fastwp_gems_shortcodes;
		$fastwp_gems_shortcodes['fastwp_gems_title'] = array( 'class' => __CLASS__, 'function' => 'shortcode' );
		$this->vc_block();
	}

	public static function shortcode( $atts, $content = '' ) {
		extract(shortcode_atts(array(
			'title'			=> 'Title',
			'tag'			=> 'h1',
			'alignment'		=> 'left',
			'title_color'	=> '',
            'line_pos'      => 'left',
			'line_color'    => '',
            'show_line'     => true,
			'margin_top'	=> '',
			'margin_bottom'	=> '',
			'extra_class'	=> ''
		), $atts));

        $class = array();

		$class[] = $title_id = 'fwp-btn-' . rand( 1000, 9999 );

        if( !empty( $extra_class ) ) {
            $class[] = esc_attr( $extra_class );
        }

        if( !in_array( $tag, array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' ) ) ) {
            $tag = 'h2';
        }

        if( $margin_top != '' || $margin_bottom != '' || !empty( $alignment ) ) {
            self::add_css( sprintf( '.fwp_title_%s{text-align:%s; margin-top:%spx; margin-bottom:%spx;}', $title_id, ( in_array( $alignment, array( 'left', 'center', 'right' ) ) ? $alignment : 'left' ), (int) $margin_top, (int) $margin_bottom ) );
        }

        if( !empty( $title_color ) ) {
            self::add_css(  sprintf( '.fwp_title_%s > %s{color:%s;}', $title_id, $tag, esc_html( $title_color ) ) );
        }

        if( !empty( $line_color ) && (boolean) $show_line ) {
            self::add_css(  sprintf( '.fwp_title_%s > %s::before, .fwp_title_%s > %s:after{background:%s;}', $title_id, $tag, $title_id, $tag, esc_html( $line_color ) ) );
        }

        if( ! (boolean) $show_line ) {
            self::add_css(  sprintf( '.fwp_title_%s > %s::before, .fwp_title_%s > %s:after{display:none;}', $title_id, $tag, $title_id, $tag ) );
        }

        $tit_style = 'title_line';

        if( $line_pos == 'top' ) {
            $tit_style = 'title_line_top';
        } else if( $line_pos == 'bottom_horizontal' ) {
            $tit_style = 'title_line_btm';
        } else if( $line_pos == 'bottom_vertical' ) {
            $tit_style = 'title_line_btm_v';
        } else if( $line_pos == 'top_bottom' ) {
            $tit_style = 'title_line_top title_line_btm';
        }

        if( !empty( $f_line_color ) ) {
            self::add_css( sprintf( '.fwp_title_%s > %s::before{color:%s;}', $title_id, $tag, esc_html( $f_line_color ) ) );
        }

		$title_markup 	= '<div class="fwp_title_%s %s">
								<%s class="%s">%s</%s>
							</div>';

		return sprintf( $title_markup, $title_id, implode( ' ', $class ), $tag, $tit_style, FastwpGemsUtils::fwp_escape( $title ), $tag );
    }

	public static function vc_block() {
		global $fastwp_gems_visual_composer_blocks;

		$fastwp_gems_visual_composer_blocks[] = array(
			"name"      => esc_html__( 'Title', 'gems' ),
			"base"      => 'fastwp_gems_title',
			"icon" 		=> get_template_directory_uri() . "/assets/img/logo-square.png",
			"category"  => esc_html__( 'Gems Elements', 'gems' ),
			"params"    => array(
				array(
					"save_always" 	=> true,
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Title",'gems'),
					"param_name" 	=> 'title',
					"value" 		=> 'Your Title',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Put your title here", 'gems' )
				),
    			array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Title Alignment", 'gems' ),
					"param_name" 	=> 'alignment',
					'value'			=> array(
							        'Left'   => 'left',
							        'Center' => 'center',
							        'Right'  => 'right',
							    	),
					"default" 		=> 'left',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose title alignment. Default: Left",'gems')
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Title Tag",'gems' ),
					"param_name" 	=> 'tag',
					'value'			=> array(
        							        'H1'    => 'h1',
        							        'H2'    => 'h2',
        							        'H3'    => 'h3',
        							        'H4'    => 'h4',
        							        'H5'    => 'h5',
        							        'H6'    => 'h6',
        							    	),
					"default" 		=> 'h2',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose a tag for title",'gems')
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Show Line",'gems' ),
					"param_name" 	=> 'show_line',
					'value'			=> array(
        							        esc_html__( 'Yes', 'gems' )   => 1,
        							        esc_html__( 'No', 'gems' )    => 0,
        							    	),
					"default" 		=> '1',
					"admin_label"	=> true,
					"description"	=> esc_html__("Choose to show or hide the line/s. Default: Yes (visible)",'gems')
				),
				array(
					"save_always" 	=> true,
					"type" 			=> 'dropdown',
					"holder" 		=> false,
					"heading" 		=> esc_html__( "Line Align", 'gems' ),
					"param_name" 	=> 'line_pos',
					'value'			=> array(
        							        esc_html__( 'Left', 'gems' )                             => 'left',
        							        esc_html__( 'Top Vertical', 'gems' )                     => 'top',
                                            esc_html__( 'Top Vertical & Bottom Horizontal', 'gems' ) =>'top_bottom',
                                            esc_html__( 'Bottom Vertical', 'gems' )                  =>'bottom_vertical',
                                            esc_html__( 'Bottom Horizontal', 'gems' )                =>'bottom_horizontal'
        							    	),
					"default" 		=> 'left',
					"admin_label"	=> true,
					"description"	=> esc_html__( "Choose line alignment or possition. Default: Left", 'gems' ),
                    "dependency"    => array( "element" => "show_line", "value" => array( "1" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Title Color",'gems'),
					"param_name" 	=> 'title_color',
					"value" 		=> '#0a0a0a',
					"admin_label"	=> true,
					"description"	=> esc_html__("Modify title color",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'colorpicker',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Line Color",'gems'),
					"param_name" 	=> "line_color",
					"value" 		=> '#0a0a0a',
					"admin_label"	=> true,
					"description"	=> esc_html__("Modify line color",'gems'),
                    "dependency"    => array( "element" => "show_line", "value" => array( "1" ) )
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
                    "edit_field_class"=> "w50_fastwp_vc",
					"heading" 		=> esc_html__("Margin Top",'gems'),
					"param_name" 	=> 'margin_top',
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Add a margin top for title holder, only numeric values",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Styling', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
                    "edit_field_class"=> "w50_fastwp_vc",
					"heading" 		=> esc_html__("Margin Bottom",'gems'),
					"param_name" 	=> 'margin_bottom',
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Add a margin bottom for title holder, only numeric values",'gems')
				),
				array(
					"save_always" 	=> true,
					"group"			=> esc_html__( 'Extra', 'gems' ),
					"type" 			=> 'textfield',
					"holder" 		=> false,
					"heading" 		=> esc_html__("Extra Class",'gems'),
					"param_name" 	=> 'extra_class',
					"value" 		=> '',
					"admin_label"	=> true,
					"description"	=> esc_html__("Use this options to add an extra class to element, you can use this for custom css",'gems')
				)
 			)
        );

	}

}

?>