<?php

class FastwpGemsFunctions {

	/**
		Register theme scripts and load them depending on global settings.
	**/
	static function register_scripts() {
		global $fastwp_gems_load_scripts;
		$fwp_themeUrl 	= defined( 'FASTWP_GEMS_MAIN_THEME_URL' ) ? FASTWP_GEMS_MAIN_THEME_URL : get_template_directory_uri();

		$deps 			= array('jquery');
		$in_footer		= true;

		foreach( $fastwp_gems_load_scripts as $script => $autoload ){
            if( is_numeric( $script ) ) {
                $script = $autoload;
                $autoload = true;
            }
			$handle = sanitize_title( $script );
			$src 	= sprintf( '%s/assets/js/%s.js', $fwp_themeUrl, $script );
			if( substr_count( $script, '//' ) ){
				$src = $script;
			}
			wp_register_script( $handle, $src, $deps, '1.0.0', $in_footer );
			if( FASTWP_GEMS_AUTOLOAD_SCRIPTS == true || $autoload ) {
				wp_enqueue_script( $handle );
			}
		}
	}

	/**
		Register theme styles and load them depending on global settings.
	**/
	static function register_styles() {
		global $fastwp_gems_load_styles;
		$fwp_themeUrl 	= defined( 'FASTWP_GEMS_MAIN_THEME_URL' ) ? FASTWP_GEMS_MAIN_THEME_URL : get_template_directory_uri();
		$in_footer	= true;
		foreach( $fastwp_gems_load_styles as $style ) {

			$handle = sanitize_title($style);
			$src 	= sprintf('%s/assets/css/%s.css', $fwp_themeUrl, $style);
			if( substr_count( $style, '//' ) ){
				$src = $style;
			}
			wp_register_style( $handle, $src);
			if(FASTWP_GEMS_AUTOLOAD_STYLES == true ){
				wp_enqueue_style($handle);
			}
		}
	}

	/**
        Add custom columns
	**/
	static function add_custom_column() {
		global $fastwp_gems_custom_posts_with_id;
		foreach( $fastwp_gems_custom_posts_with_id as $custom_post => $fields ){
			add_filter( 'manage_edit-' . $custom_post . '_columns', array('FastwpGemsActions', 'set_custom_edit_post_columns') );
            if( is_array( $fields ) && in_array( 'thumb', $fields ) ) {
			    add_filter( 'manage_edit-' . $custom_post . '_columns', array('FastwpGemsActions', 'set_custom_preview_post_columns') );
            }
			add_action( 'manage_' . $custom_post . '_posts_custom_column' , array('FastwpGemsActions', 'custom_ID_column'), 10, 2 );
		}
	}

	/**
        Add custom columns
	**/
	static function add_extra_scripts( $scripts ) {
		if( FASTWP_GEMS_AUTOLOAD_SCRIPTS == true ) return;

		$scripts = explode( ',', $scripts );
		foreach( $scripts as $script ) {
			$handle = sanitize_title( $script );
			wp_enqueue_script( $handle );
		}
	}

}

add_action( 'init', array( 'FastwpGemsFunctions', 'add_custom_column' ) );
add_action( 'wp_enqueue_scripts', array( 'FastwpGemsFunctions', 'register_styles'));
add_action( 'fastwp_gems_enqueue_script', array( 'FastwpGemsFunctions', 'add_extra_scripts' ) );
add_action( 'wp_enqueue_scripts', array( 'FastwpGemsFunctions', 'register_scripts' ) );