<?php

class FastwpGemsUtils {

    public static function fwp_escape( $html ) {
        $allowed_tags = array(
            'a' => array( 'class' => array(), 'href'  => array(), 'rel'   => array(), 'title' => array(), 'style' => array() ),
            'abbr' => array( 'title' => array() ),
            'b' => array(),
            'blockquote' => array( 'cite'  => array() ),
            'br' => array(),
            'cite' => array( 'title' => array() ),
            'code' => array(),
            'del' => array( 'datetime' => array(), 'title' => array() ),
            'dd' => array(),
            'div' => array( 'class' => array(), 'title' => array(), 'style' => array() ),
            'dl' => array(),
            'dt' => array(),
            'em' => array(),
            'h1' => array( 'class' => array() ),
            'h2' => array( 'class' => array() ),
            'h3' => array( 'class' => array() ),
            'h4' => array( 'class' => array() ),
            'h5' => array( 'class' => array() ),
            'h6' => array( 'class' => array() ),
            'i' => array( 'class' => array() ),
            'img' => array( 'alt' => array(), 'class' => array(), 'height' => array(), 'src' => array(), 'width' => array() ),
            'li' => array( 'class' => array() ),
            'ol' => array( 'class' => array() ),
            'p' => array( 'class' => array() ),
            'i' => array( 'class' => array() ),
            'q' => array( 'cite' => array(), 'title' => array() ),
            'span' => array( 'class' => array(), 'title' => array(), 'style' => array() ),
            'strike' => array(),
            'strong' => array(),
            'small' => array(),
            'ul' => array( 'class' => array() )
        );
        return wp_kses( $html, $allowed_tags );
    }
            
	public static function url_from_vc( $link = '' ) {
	    $link = urldecode( $link );
        if( empty( $link ) ) return array( 'title' => '', 'url' => '', 'target' => '' );
        $lnk = array();
        foreach( explode( '|', $link ) as $nlink ) {
            if( !empty( $nlink ) )
            $lnk[strstr($nlink, ':', true)] = substr( strstr($nlink, ':'), 1 );
        }
        return array_merge( array( 'title' => '', 'url' => '', 'target' => '_self' ), $lnk );
    }

	public static function param_group_vc( $text = '' ) {
        return json_decode( urldecode( $text ), true );
    }

    public static function hex2rgba( $color, $opacity = false ) {
    	$default = 'rgb(0,0,0)';

    	if( empty($color ) ) return $default;

        if( $color[0] == '#' ) {
            $color = substr( $color, 1 );
        }

            if ( strlen( $color ) == 6 ) {
                $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
            } elseif ( strlen( $color ) == 3 ) {
                $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
            } else {
                return $default;
            }

            //Convert hexadec to rgb
            $rgb =  array_map('hexdec', $hex);

            //Check if opacity is set(rgba or rgb)
            if($opacity){
            	if( abs( $opacity ) > 1 ) $opacity = 1.0;
            	$output = 'rgba( ' . implode( ",", $rgb ) . ',' . $opacity . ')';
            } else {
            	$output = 'rgb(' . implode( ",", $rgb ) . ')';
            }

            return $output;
    }

    static function get_template_part( $file = '' ) {
        if( empty( $file ) ) return '';
        ob_start();
        get_template_part( $file );
        $content = ob_get_clean();
        return $content;
    }

    public static function body_attribute() {
        global $fastwp_extra_body_attr;

        $atts = '';
        if( !empty( $fastwp_extra_body_attr ) ) {
            if( is_array( $fastwp_extra_body_attr ) ) {
                $atts = ' ' . implode( ' ', $fastwp_extra_body_attr );
            } else {
                $atts = ' ' . $fastwp_extra_body_attr;
            }
        }
        return $atts;
    }

    public static function entypo_icons() {
        $icons = array(
            array( 'icon-add-to-list' => esc_html__( 'Add-to-list', 'gems' ) ), array( 'icon-add-user' => esc_html__( 'Add-user', 'gems' ) ), array( 'icon-address' => esc_html__( 'Address', 'gems' ) ),
            array( 'icon-adjust' => esc_html__( 'Adjust', 'gems' ) ), array( 'icon-air' => esc_html__( 'Air', 'gems' ) ), array( 'icon-aircraft-landing' => esc_html__( 'Aircraft-landing', 'gems' ) ),
            array( 'icon-aircraft-take-off' => esc_html__( 'Aircraft-take-off', 'gems' ) ), array( 'icon-aircraft' => esc_html__( 'Aircraft', 'gems' ) ), array( 'icon-align-bottom' => esc_html__( 'Align-bottom', 'gems' ) ),
            array( 'icon-align-horizontal-middle' => esc_html__( 'Align-horizontal-middle', 'gems' ) ), array( 'icon-align-left' => esc_html__( 'Align-left', 'gems' ) ), array( 'icon-align-right' => esc_html__( 'Align-right', 'gems' ) ),
            array( 'icon-align-top' => esc_html__( 'Align-top', 'gems' ) ), array( 'icon-align-vertical-middle' => esc_html__( 'Align-vertical-middle', 'gems' ) ), array( 'icon-archive' => esc_html__( 'Archive', 'gems' ) ),
            array( 'icon-area-graph' => esc_html__( 'Area-graph', 'gems' ) ), array( 'icon-arrow-bold-down' => esc_html__( 'Arrow-bold-down', 'gems' ) ), array( 'icon-arrow-bold-left' => esc_html__( 'Arrow-bold-left', 'gems' ) ),
            array( 'icon-arrow-bold-right' => esc_html__( 'Arrow-bold-right', 'gems' ) ), array( 'icon-arrow-bold-up' => esc_html__( 'Arrow-bold-up', 'gems' ) ), array( 'icon-arrow-down' => esc_html__( 'Arrow-down', 'gems' ) ),
            array( 'icon-arrow-left' => esc_html__( 'Arrow-left', 'gems' ) ), array( 'icon-arrow-long-down' => esc_html__( 'Arrow-long-down', 'gems' ) ), array( 'icon-arrow-long-left' => esc_html__( 'Arrow-long-left', 'gems' ) ),
            array( 'icon-arrow-long-right' => esc_html__( 'Arrow-long-right', 'gems' ) ), array( 'icon-arrow-long-up' => esc_html__( 'Arrow-long-up', 'gems' ) ), array( 'icon-arrow-right' => esc_html__( 'Arrow-right', 'gems' ) ),
            array( 'icon-arrow-up' => esc_html__( 'Arrow-up', 'gems' ) ), array( 'icon-arrow-with-circle-down' => esc_html__( 'Arrow-with-circle-down', 'gems' ) ), array( 'icon-arrow-with-circle-left' => esc_html__( 'Arrow-with-circle-left', 'gems' ) ),
            array( 'icon-arrow-with-circle-right' => esc_html__( 'Arrow-with-circle-right', 'gems' ) ), array( 'icon-arrow-with-circle-up' => esc_html__( 'Arrow-with-circle-up', 'gems' ) ), array( 'icon-attachment' => esc_html__( 'Attachment', 'gems' ) ),
            array( 'icon-awareness-ribbon' => esc_html__( 'Awareness-ribbon', 'gems' ) ), array( 'icon-back-in-time' => esc_html__( 'Back-in-time', 'gems' ) ), array( 'icon-back' => esc_html__( 'Back', 'gems' ) ),
            array( 'icon-bar-graph' => esc_html__( 'Bar-graph', 'gems' ) ), array( 'icon-battery' => esc_html__( 'Battery', 'gems' ) ), array( 'icon-beamed-note' => esc_html__( 'Beamed-note', 'gems' ) ),
            array( 'icon-bell' => esc_html__( 'Bell', 'gems' ) ), array( 'icon-blackboard' => esc_html__( 'Blackboard', 'gems' ) ), array( 'icon-block' => esc_html__( 'Block', 'gems' ) ),
            array( 'icon-book' => esc_html__( 'Book', 'gems' ) ), array( 'icon-bookmark' => esc_html__( 'Bookmark', 'gems' ) ), array( 'icon-bookmarks' => esc_html__( 'Bookmarks', 'gems' ) ),
            array( 'icon-bowl' => esc_html__( 'Bowl', 'gems' ) ), array( 'icon-box' => esc_html__( 'Box', 'gems' ) ), array( 'icon-briefcase' => esc_html__( 'Briefcase', 'gems' ) ),
            array( 'icon-browser' => esc_html__( 'Browser', 'gems' ) ), array( 'icon-brush' => esc_html__( 'Brush', 'gems' ) ), array( 'icon-bucket' => esc_html__( 'Bucket', 'gems' ) ),
            array( 'icon-bug' => esc_html__( 'Bug', 'gems' ) ), array( 'icon-cake' => esc_html__( 'Cake', 'gems' ) ), array( 'icon-calculator' => esc_html__( 'Calculator', 'gems' ) ),
            array( 'icon-calendar' => esc_html__( 'Calendar', 'gems' ) ), array( 'icon-camera' => esc_html__( 'Camera', 'gems' ) ), array( 'icon-ccw' => esc_html__( 'Ccw', 'gems' ) ),
            array( 'icon-chat' => esc_html__( 'Chat', 'gems' ) ), array( 'icon-check' => esc_html__( 'Check', 'gems' ) ), array( 'icon-down' => esc_html__( 'Down', 'gems' ) ),
            array( 'icon-left' => esc_html__( 'Left', 'gems' ) ), array( 'icon-right' => esc_html__( 'Right', 'gems' ) ), array( 'icon-down-open-mini' => esc_html__( 'Down-open-mini', 'gems' ) ),
            array( 'icon-left-open-mini' => esc_html__( 'Left-open-mini', 'gems' ) ), array( 'icon-right-open-mini' => esc_html__( 'Right-open-mini', 'gems' ) ), array( 'icon-up-open-mini' => esc_html__( 'Up-open-mini', 'gems' ) ),
            array( 'icon-down-open-big' => esc_html__( 'Down-open-big', 'gems' ) ), array( 'icon-left-open-big' => esc_html__( 'Left-open-big', 'gems' ) ), array( 'icon-right-open-big' => esc_html__( 'Right-open-big', 'gems' ) ),
            array( 'icon-up-open-big' => esc_html__( 'Up-open-big', 'gems' ) ), array( 'icon-up' => esc_html__( 'Up', 'gems' ) ), array( 'icon-down-circled' => esc_html__( 'Down-circled', 'gems' ) ),
            array( 'icon-left-circled' => esc_html__( 'Left-circled', 'gems' ) ), array( 'icon-right-circled' => esc_html__( 'Right-circled', 'gems' ) ), array( 'icon-up-circled' => esc_html__( 'Up-circled', 'gems' ) ),
            array( 'icon-circle-with-cross' => esc_html__( 'Circle-with-cross', 'gems' ) ), array( 'icon-circle-with-minus' => esc_html__( 'Circle-with-minus', 'gems' ) ), array( 'icon-circle-with-plus' => esc_html__( 'Circle-with-plus', 'gems' ) ),
            array( 'icon-circle' => esc_html__( 'Circle', 'gems' ) ), array( 'icon-circular-graph' => esc_html__( 'Circular-graph', 'gems' ) ), array( 'icon-clapperboard' => esc_html__( 'Clapperboard', 'gems' ) ),
            array( 'icon-classic-computer' => esc_html__( 'Classic-computer', 'gems' ) ), array( 'icon-clipboard' => esc_html__( 'Clipboard', 'gems' ) ), array( 'icon-clock' => esc_html__( 'Clock', 'gems' ) ),
            array( 'icon-cloud' => esc_html__( 'Cloud', 'gems' ) ), array( 'icon-code' => esc_html__( 'Code', 'gems' ) ), array( 'icon-cog' => esc_html__( 'Cog', 'gems' ) ),
            array( 'icon-colours' => esc_html__( 'Colours', 'gems' ) ), array( 'icon-compass' => esc_html__( 'Compass', 'gems' ) ), array( 'icon-fast-backward' => esc_html__( 'Fast-backward', 'gems' ) ),
            array( 'icon-fast-forward' => esc_html__( 'Fast-forward', 'gems' ) ), array( 'icon-jump-to-start' => esc_html__( 'Jump-to-start', 'gems' ) ), array( 'icon-next' => esc_html__( 'Next', 'gems' ) ),
            array( 'icon-paus' => esc_html__( 'Paus', 'gems' ) ), array( 'icon-play' => esc_html__( 'Play', 'gems' ) ), array( 'icon-record' => esc_html__( 'Record', 'gems' ) ),
            array( 'icon-stop' => esc_html__( 'Stop', 'gems' ) ), array( 'icon-volume' => esc_html__( 'Volume', 'gems' ) ), array( 'icon-copy' => esc_html__( 'Copy', 'gems' ) ),
            array( 'icon-creative-commons-attribution' => esc_html__( 'Creative-commons-attribution', 'gems' ) ), array( 'icon-creative-commons-noderivs' => esc_html__( 'Creative-commons-noderivs', 'gems' ) ), array( 'icon-creative-commons-noncommercial-eu' => esc_html__( 'Creative-commons-noncommercial-eu', 'gems' ) ),
            array( 'icon-creative-commons-noncommercial-us' => esc_html__( 'Creative-commons-noncommercial-us', 'gems' ) ), array( 'icon-creative-commons-public-domain' => esc_html__( 'Creative-commons-public-domain', 'gems' ) ), array( 'icon-creative-commons-remix' => esc_html__( 'Creative-commons-remix', 'gems' ) ),
            array( 'icon-creative-commons-share' => esc_html__( 'Creative-commons-share', 'gems' ) ), array( 'icon-creative-commons-sharealike' => esc_html__( 'Creative-commons-sharealike', 'gems' ) ), array( 'icon-creative-commons' => esc_html__( 'Creative-commons', 'gems' ) ),
            array( 'icon-credit-card' => esc_html__( 'Credit-card', 'gems' ) ), array( 'icon-credit' => esc_html__( 'Credit', 'gems' ) ), array( 'icon-crop' => esc_html__( 'Crop', 'gems' ) ),
            array( 'icon-cancel' => esc_html__( 'Cancel', 'gems' ) ), array( 'icon-cup' => esc_html__( 'Cup', 'gems' ) ), array( 'icon-cw' => esc_html__( 'Cw', 'gems' ) ),
            array( 'icon-cycle' => esc_html__( 'Cycle', 'gems' ) ), array( 'icon-database' => esc_html__( 'Database', 'gems' ) ), array( 'icon-dial-pad' => esc_html__( 'Dial-pad', 'gems' ) ),
            array( 'icon-direction' => esc_html__( 'Direction', 'gems' ) ), array( 'icon-document-landscape' => esc_html__( 'Document-landscape', 'gems' ) ), array( 'icon-document' => esc_html__( 'Document', 'gems' ) ),
            array( 'icon-documents' => esc_html__( 'Documents', 'gems' ) ), array( 'icon-dot-single' => esc_html__( 'Dot-single', 'gems' ) ), array( 'icon-dots-three-horizontal' => esc_html__( 'Dots-three-horizontal', 'gems' ) ),
            array( 'icon-dots-three-vertical' => esc_html__( 'Dots-three-vertical', 'gems' ) ), array( 'icon-dots-two-horizontal' => esc_html__( 'Dots-two-horizontal', 'gems' ) ), array( 'icon-dots-two-vertical' => esc_html__( 'Dots-two-vertical', 'gems' ) ),
            array( 'icon-download' => esc_html__( 'Download', 'gems' ) ), array( 'icon-drink' => esc_html__( 'Drink', 'gems' ) ), array( 'icon-drive' => esc_html__( 'Drive', 'gems' ) ),
            array( 'icon-drop' => esc_html__( 'Drop', 'gems' ) ), array( 'icon-edit' => esc_html__( 'Edit', 'gems' ) ), array( 'icon-email' => esc_html__( 'Email', 'gems' ) ),
            array( 'icon-emoji-flirt' => esc_html__( 'Emoji-flirt', 'gems' ) ), array( 'icon-emoji-happy' => esc_html__( 'Emoji-happy', 'gems' ) ), array( 'icon-emoji-neutral' => esc_html__( 'Emoji-neutral', 'gems' ) ),
            array( 'icon-emoji-sad' => esc_html__( 'Emoji-sad', 'gems' ) ), array( 'icon-erase' => esc_html__( 'Erase', 'gems' ) ), array( 'icon-eraser' => esc_html__( 'Eraser', 'gems' ) ),
            array( 'icon-export' => esc_html__( 'Export', 'gems' ) ), array( 'icon-eye-with-line' => esc_html__( 'Eye-with-line', 'gems' ) ), array( 'icon-eye' => esc_html__( 'Eye', 'gems' ) ),
            array( 'icon-feather' => esc_html__( 'Feather', 'gems' ) ), array( 'icon-fingerprint' => esc_html__( 'Fingerprint', 'gems' ) ), array( 'icon-flag' => esc_html__( 'Flag', 'gems' ) ),
            array( 'icon-flash' => esc_html__( 'Flash', 'gems' ) ), array( 'icon-flashlight' => esc_html__( 'Flashlight', 'gems' ) ), array( 'icon-flat-brush' => esc_html__( 'Flat-brush', 'gems' ) ),
            array( 'icon-flow-branch' => esc_html__( 'Flow-branch', 'gems' ) ), array( 'icon-flow-cascade' => esc_html__( 'Flow-cascade', 'gems' ) ), array( 'icon-flow-line' => esc_html__( 'Flow-line', 'gems' ) ),
            array( 'icon-flow-parallel' => esc_html__( 'Flow-parallel', 'gems' ) ), array( 'icon-flow-tree' => esc_html__( 'Flow-tree', 'gems' ) ), array( 'icon-flower' => esc_html__( 'Flower', 'gems' ) ),
            array( 'icon-folder-images' => esc_html__( 'Folder-images', 'gems' ) ), array( 'icon-folder-music' => esc_html__( 'Folder-music', 'gems' ) ), array( 'icon-folder-video' => esc_html__( 'Folder-video', 'gems' ) ),
            array( 'icon-folder' => esc_html__( 'Folder', 'gems' ) ), array( 'icon-forward' => esc_html__( 'Forward', 'gems' ) ), array( 'icon-funnel' => esc_html__( 'Funnel', 'gems' ) ),
            array( 'icon-game-controller' => esc_html__( 'Game-controller', 'gems' ) ), array( 'icon-gauge' => esc_html__( 'Gauge', 'gems' ) ), array( 'icon-globe' => esc_html__( 'Globe', 'gems' ) ),
            array( 'icon-graduation-cap' => esc_html__( 'Graduation-cap', 'gems' ) ), array( 'icon-grid' => esc_html__( 'Grid', 'gems' ) ), array( 'icon-hair-cross' => esc_html__( 'Hair-cross', 'gems' ) ),
            array( 'icon-hand' => esc_html__( 'Hand', 'gems' ) ), array( 'icon-heart-outlined' => esc_html__( 'Heart-outlined', 'gems' ) ), array( 'icon-heart' => esc_html__( 'Heart', 'gems' ) ),
            array( 'icon-help-with-circle' => esc_html__( 'Help-with-circle', 'gems' ) ), array( 'icon-help' => esc_html__( 'Help', 'gems' ) ), array( 'icon-home' => esc_html__( 'Home', 'gems' ) ),
            array( 'icon-hour-glass' => esc_html__( 'Hour-glass', 'gems' ) ), array( 'icon-image-inverted' => esc_html__( 'Image-inverted', 'gems' ) ), array( 'icon-image' => esc_html__( 'Image', 'gems' ) ),
            array( 'icon-images' => esc_html__( 'Images', 'gems' ) ), array( 'icon-inbox' => esc_html__( 'Inbox', 'gems' ) ), array( 'icon-infinity' => esc_html__( 'Infinity', 'gems' ) ),
            array( 'icon-info-with-circle' => esc_html__( 'Info-with-circle', 'gems' ) ), array( 'icon-info' => esc_html__( 'Info', 'gems' ) ), array( 'icon-install' => esc_html__( 'Install', 'gems' ) ),
            array( 'icon-key' => esc_html__( 'Key', 'gems' ) ), array( 'icon-keyboard' => esc_html__( 'Keyboard', 'gems' ) ), array( 'icon-lab-flask' => esc_html__( 'Lab-flask', 'gems' ) ),
            array( 'icon-landline' => esc_html__( 'Landline', 'gems' ) ), array( 'icon-language' => esc_html__( 'Language', 'gems' ) ), array( 'icon-laptop' => esc_html__( 'Laptop', 'gems' ) ),
            array( 'icon-layers' => esc_html__( 'Layers', 'gems' ) ), array( 'icon-leaf' => esc_html__( 'Leaf', 'gems' ) ), array( 'icon-level-down' => esc_html__( 'Level-down', 'gems' ) ),
            array( 'icon-level-up' => esc_html__( 'Level-up', 'gems' ) ), array( 'icon-lifebuoy' => esc_html__( 'Lifebuoy', 'gems' ) ), array( 'icon-light-bulb' => esc_html__( 'Light-bulb', 'gems' ) ),
            array( 'icon-light-down' => esc_html__( 'Light-down', 'gems' ) ), array( 'icon-light-up' => esc_html__( 'Light-up', 'gems' ) ), array( 'icon-line-graph' => esc_html__( 'Line-graph', 'gems' ) ),
            array( 'icon-link' => esc_html__( 'Link', 'gems' ) ), array( 'icon-list' => esc_html__( 'List', 'gems' ) ), array( 'icon-location-pin' => esc_html__( 'Location-pin', 'gems' ) ),
            array( 'icon-location' => esc_html__( 'Location', 'gems' ) ), array( 'icon-lock-open' => esc_html__( 'Lock-open', 'gems' ) ), array( 'icon-lock' => esc_html__( 'Lock', 'gems' ) ),
            array( 'icon-log-out' => esc_html__( 'Log-out', 'gems' ) ), array( 'icon-login' => esc_html__( 'Login', 'gems' ) ), array( 'icon-loop' => esc_html__( 'Loop', 'gems' ) ),
            array( 'icon-magnet' => esc_html__( 'Magnet', 'gems' ) ), array( 'icon-magnifying-glass' => esc_html__( 'Magnifying-glass', 'gems' ) ), array( 'icon-mail' => esc_html__( 'Mail', 'gems' ) ),
            array( 'icon-man' => esc_html__( 'Man', 'gems' ) ), array( 'icon-map' => esc_html__( 'Map', 'gems' ) ), array( 'icon-mask' => esc_html__( 'Mask', 'gems' ) ),
            array( 'icon-medal' => esc_html__( 'Medal', 'gems' ) ), array( 'icon-megaphone' => esc_html__( 'Megaphone', 'gems' ) ), array( 'icon-menu' => esc_html__( 'Menu', 'gems' ) ),
            array( 'icon-merge' => esc_html__( 'Merge', 'gems' ) ), array( 'icon-message' => esc_html__( 'Message', 'gems' ) ), array( 'icon-mic' => esc_html__( 'Mic', 'gems' ) ),
            array( 'icon-minus' => esc_html__( 'Minus', 'gems' ) ), array( 'icon-mobile' => esc_html__( 'Mobile', 'gems' ) ), array( 'icon-modern-mic' => esc_html__( 'Modern-mic', 'gems' ) ),
            array( 'icon-moon' => esc_html__( 'Moon', 'gems' ) ), array( 'icon-mouse-pointer' => esc_html__( 'Mouse-pointer', 'gems' ) ), array( 'icon-mouse' => esc_html__( 'Mouse', 'gems' ) ),
            array( 'icon-music' => esc_html__( 'Music', 'gems' ) ), array( 'icon-network' => esc_html__( 'Network', 'gems' ) ), array( 'icon-new-message' => esc_html__( 'New-message', 'gems' ) ),
            array( 'icon-new' => esc_html__( 'New', 'gems' ) ), array( 'icon-news' => esc_html__( 'News', 'gems' ) ), array( 'icon-newsletter' => esc_html__( 'Newsletter', 'gems' ) ),
            array( 'icon-note' => esc_html__( 'Note', 'gems' ) ), array( 'icon-notification' => esc_html__( 'Notification', 'gems' ) ), array( 'icon-notifications-off' => esc_html__( 'Notifications-off', 'gems' ) ),
            array( 'icon-old-mobile' => esc_html__( 'Old-mobile', 'gems' ) ), array( 'icon-old-phone' => esc_html__( 'Old-phone', 'gems' ) ), array( 'icon-open-book' => esc_html__( 'Open-book', 'gems' ) ),
            array( 'icon-palette' => esc_html__( 'Palette', 'gems' ) ), array( 'icon-paper-plane' => esc_html__( 'Paper-plane', 'gems' ) ), array( 'icon-pencil' => esc_html__( 'Pencil', 'gems' ) ),
            array( 'icon-phone' => esc_html__( 'Phone', 'gems' ) ), array( 'icon-pie-chart' => esc_html__( 'Pie-chart', 'gems' ) ), array( 'icon-pin' => esc_html__( 'Pin', 'gems' ) ),
            array( 'icon-plus' => esc_html__( 'Plus', 'gems' ) ), array( 'icon-popup' => esc_html__( 'Popup', 'gems' ) ), array( 'icon-power-plug' => esc_html__( 'Power-plug', 'gems' ) ),
            array( 'icon-price-ribbon' => esc_html__( 'Price-ribbon', 'gems' ) ), array( 'icon-price-tag' => esc_html__( 'Price-tag', 'gems' ) ), array( 'icon-print' => esc_html__( 'Print', 'gems' ) ),
            array( 'icon-progress-empty' => esc_html__( 'Progress-empty', 'gems' ) ), array( 'icon-progress-full' => esc_html__( 'Progress-full', 'gems' ) ), array( 'icon-progress-one' => esc_html__( 'Progress-one', 'gems' ) ),
            array( 'icon-progress-two' => esc_html__( 'Progress-two', 'gems' ) ), array( 'icon-publish' => esc_html__( 'Publish', 'gems' ) ), array( 'icon-quote' => esc_html__( 'Quote', 'gems' ) ),
            array( 'icon-radio' => esc_html__( 'Radio', 'gems' ) ), array( 'icon-remove-user' => esc_html__( 'Remove-user', 'gems' ) ), array( 'icon-reply-all' => esc_html__( 'Reply-all', 'gems' ) ),
            array( 'icon-reply' => esc_html__( 'Reply', 'gems' ) ), array( 'icon-resize-100' => esc_html__( 'Resize-100', 'gems' ) ), array( 'icon-resize-full-screen' => esc_html__( 'Resize-full-screen', 'gems' ) ),
            array( 'icon-retweet' => esc_html__( 'Retweet', 'gems' ) ), array( 'icon-rocket' => esc_html__( 'Rocket', 'gems' ) ), array( 'icon-round-brush' => esc_html__( 'Round-brush', 'gems' ) ),
            array( 'icon-rss' => esc_html__( 'Rss', 'gems' ) ), array( 'icon-ruler' => esc_html__( 'Ruler', 'gems' ) ), array( 'icon-save' => esc_html__( 'Save', 'gems' ) ),
            array( 'icon-scissors' => esc_html__( 'Scissors', 'gems' ) ), array( 'icon-select-arrows' => esc_html__( 'Select-arrows', 'gems' ) ), array( 'icon-share-alternative' => esc_html__( 'Share-alternative', 'gems' ) ),
            array( 'icon-share' => esc_html__( 'Share', 'gems' ) ), array( 'icon-shareable' => esc_html__( 'Shareable', 'gems' ) ), array( 'icon-shield' => esc_html__( 'Shield', 'gems' ) ),
            array( 'icon-shop' => esc_html__( 'Shop', 'gems' ) ), array( 'icon-shopping-bag' => esc_html__( 'Shopping-bag', 'gems' ) ), array( 'icon-shopping-basket' => esc_html__( 'Shopping-basket', 'gems' ) ),
            array( 'icon-shopping-cart' => esc_html__( 'Shopping-cart', 'gems' ) ), array( 'icon-shuffle' => esc_html__( 'Shuffle', 'gems' ) ), array( 'icon-signal' => esc_html__( 'Signal', 'gems' ) ),
            array( 'icon-sound-mix' => esc_html__( 'Sound-mix', 'gems' ) ), array( 'icon-sound-mute' => esc_html__( 'Sound-mute', 'gems' ) ), array( 'icon-sound' => esc_html__( 'Sound', 'gems' ) ),
            array( 'icon-sports-club' => esc_html__( 'Sports-club', 'gems' ) ), array( 'icon-spreadsheet' => esc_html__( 'Spreadsheet', 'gems' ) ), array( 'icon-squared-cross' => esc_html__( 'Squared-cross', 'gems' ) ),
            array( 'icon-squared-minus' => esc_html__( 'Squared-minus', 'gems' ) ), array( 'icon-squared-plus' => esc_html__( 'Squared-plus', 'gems' ) ), array( 'icon-star-outlined' => esc_html__( 'Star-outlined', 'gems' ) ),
            array( 'icon-star' => esc_html__( 'Star', 'gems' ) ), array( 'icon-stopwatch' => esc_html__( 'Stopwatch', 'gems' ) ), array( 'icon-suitcase' => esc_html__( 'Suitcase', 'gems' ) ),
            array( 'icon-swap' => esc_html__( 'Swap', 'gems' ) ), array( 'icon-sweden' => esc_html__( 'Sweden', 'gems' ) ), array( 'icon-switch' => esc_html__( 'Switch', 'gems' ) ),
            array( 'icon-tablet-mobile-combo' => esc_html__( 'Tablet-mobile-combo', 'gems' ) ), array( 'icon-tablet' => esc_html__( 'Tablet', 'gems' ) ), array( 'icon-tag' => esc_html__( 'Tag', 'gems' ) ),
            array( 'icon-text-document-inverted' => esc_html__( 'Text-document-inverted', 'gems' ) ), array( 'icon-text-document' => esc_html__( 'Text-document', 'gems' ) ), array( 'icon-text' => esc_html__( 'Text', 'gems' ) ),
            array( 'icon-thermometer' => esc_html__( 'Thermometer', 'gems' ) ), array( 'icon-thumbs-down' => esc_html__( 'Thumbs-down', 'gems' ) ), array( 'icon-thumbs-up' => esc_html__( 'Thumbs-up', 'gems' ) ),
            array( 'icon-thunder-cloud' => esc_html__( 'Thunder-cloud', 'gems' ) ), array( 'icon-ticket' => esc_html__( 'Ticket', 'gems' ) ), array( 'icon-time-slot' => esc_html__( 'Time-slot', 'gems' ) ),
            array( 'icon-tools' => esc_html__( 'Tools', 'gems' ) ), array( 'icon-traffic-cone' => esc_html__( 'Traffic-cone', 'gems' ) ), array( 'icon-trash' => esc_html__( 'Trash', 'gems' ) ),
            array( 'icon-tree' => esc_html__( 'Tree', 'gems' ) ), array( 'icon-triangle-down' => esc_html__( 'Triangle-down', 'gems' ) ), array( 'icon-triangle-left' => esc_html__( 'Triangle-left', 'gems' ) ),
            array( 'icon-triangle-right' => esc_html__( 'Triangle-right', 'gems' ) ), array( 'icon-triangle-up' => esc_html__( 'Triangle-up', 'gems' ) ), array( 'icon-trophy' => esc_html__( 'Trophy', 'gems' ) ),
            array( 'icon-tv' => esc_html__( 'Tv', 'gems' ) ), array( 'icon-typing' => esc_html__( 'Typing', 'gems' ) ), array( 'icon-uninstall' => esc_html__( 'Uninstall', 'gems' ) ),
            array( 'icon-unread' => esc_html__( 'Unread', 'gems' ) ), array( 'icon-untag' => esc_html__( 'Untag', 'gems' ) ), array( 'icon-upload-to-cloud' => esc_html__( 'Upload-to-cloud', 'gems' ) ),
            array( 'icon-upload' => esc_html__( 'Upload', 'gems' ) ), array( 'icon-user' => esc_html__( 'User', 'gems' ) ), array( 'icon-users' => esc_html__( 'Users', 'gems' ) ),
            array( 'icon-v-card' => esc_html__( 'V-card', 'gems' ) ), array( 'icon-video-camera' => esc_html__( 'Video-camera', 'gems' ) ), array( 'icon-video' => esc_html__( 'Video', 'gems' ) ),
            array( 'icon-vinyl' => esc_html__( 'Vinyl', 'gems' ) ), array( 'icon-voicemail' => esc_html__( 'Voicemail', 'gems' ) ), array( 'icon-wallet' => esc_html__( 'Wallet', 'gems' ) ),
            array( 'icon-warning' => esc_html__( 'Warning', 'gems' ) ), array( 'icon-water' => esc_html__( 'Water', 'gems' ) ), array( 'icon-px-with-circle' => esc_html__( 'Px-with-circle', 'gems' ) ),
            array( 'icon-px' => esc_html__( 'Px', 'gems' ) ), array( 'icon-app-store' => esc_html__( 'App-store', 'gems' ) ), array( 'icon-baidu' => esc_html__( 'Baidu', 'gems' ) ),
            array( 'icon-basecamp' => esc_html__( 'Basecamp', 'gems' ) ), array( 'icon-behance' => esc_html__( 'Behance', 'gems' ) ), array( 'icon-creative-cloud' => esc_html__( 'Creative-cloud', 'gems' ) ),
            array( 'icon-dribbble-with-circle' => esc_html__( 'Dribbble-with-circle', 'gems' ) ), array( 'icon-dribbble' => esc_html__( 'Dribbble', 'gems' ) ), array( 'icon-dropbox' => esc_html__( 'Dropbox', 'gems' ) ),
            array( 'icon-evernote' => esc_html__( 'Evernote', 'gems' ) ), array( 'icon-facebook-with-circle' => esc_html__( 'Facebook-with-circle', 'gems' ) ), array( 'icon-facebook' => esc_html__( 'Facebook', 'gems' ) ),
            array( 'icon-flattr' => esc_html__( 'Flattr', 'gems' ) ), array( 'icon-flickr-with-circle' => esc_html__( 'Flickr-with-circle', 'gems' ) ), array( 'icon-flickr' => esc_html__( 'Flickr', 'gems' ) ),
            array( 'icon-foursquare' => esc_html__( 'Foursquare', 'gems' ) ), array( 'icon-github-with-circle' => esc_html__( 'Github-with-circle', 'gems' ) ), array( 'icon-github' => esc_html__( 'Github', 'gems' ) ),
            array( 'icon-google-drive' => esc_html__( 'Google-drive', 'gems' ) ), array( 'icon-google-hangouts' => esc_html__( 'Google-hangouts', 'gems' ) ), array( 'icon-google-play' => esc_html__( 'Google-play', 'gems' ) ),
            array( 'icon-google-with-circle' => esc_html__( 'Google-with-circle', 'gems' ) ), array( 'icon-google' => esc_html__( 'Google', 'gems' ) ), array( 'icon-grooveshark' => esc_html__( 'Grooveshark', 'gems' ) ),
            array( 'icon-houzz' => esc_html__( 'Houzz', 'gems' ) ), array( 'icon-icloud' => esc_html__( 'Icloud', 'gems' ) ), array( 'icon-instagram-with-circle' => esc_html__( 'Instagram-with-circle', 'gems' ) ),
            array( 'icon-instagram' => esc_html__( 'Instagram', 'gems' ) ), array( 'icon-lastfm-with-circle' => esc_html__( 'Lastfm-with-circle', 'gems' ) ), array( 'icon-lastfm' => esc_html__( 'Lastfm', 'gems' ) ),
            array( 'icon-linkedin-with-circle' => esc_html__( 'Linkedin-with-circle', 'gems' ) ), array( 'icon-linkedin' => esc_html__( 'Linkedin', 'gems' ) ), array( 'icon-mail-with-circle' => esc_html__( 'Mail-with-circle', 'gems' ) ),
            array( 'icon-medium-with-circle' => esc_html__( 'Medium-with-circle', 'gems' ) ), array( 'icon-medium' => esc_html__( 'Medium', 'gems' ) ), array( 'icon-mixi' => esc_html__( 'Mixi', 'gems' ) ),
            array( 'icon-onedrive' => esc_html__( 'Onedrive', 'gems' ) ), array( 'icon-paypal' => esc_html__( 'Paypal', 'gems' ) ), array( 'icon-picasa' => esc_html__( 'Picasa', 'gems' ) ),
            array( 'icon-pinterest-with-circle' => esc_html__( 'Pinterest-with-circle', 'gems' ) ), array( 'icon-pinterest' => esc_html__( 'Pinterest', 'gems' ) ), array( 'icon-qq-with-circle' => esc_html__( 'Qq-with-circle', 'gems' ) ),
            array( 'icon-qq' => esc_html__( 'Qq', 'gems' ) ), array( 'icon-raft-with-circle' => esc_html__( 'Raft-with-circle', 'gems' ) ), array( 'icon-raft' => esc_html__( 'Raft', 'gems' ) ),
            array( 'icon-rainbow' => esc_html__( 'Rainbow', 'gems' ) ), array( 'icon-rdio-with-circle' => esc_html__( 'Rdio-with-circle', 'gems' ) ), array( 'icon-rdio' => esc_html__( 'Rdio', 'gems' ) ),
            array( 'icon-renren' => esc_html__( 'Renren', 'gems' ) ), array( 'icon-scribd' => esc_html__( 'Scribd', 'gems' ) ), array( 'icon-sina-weibo' => esc_html__( 'Sina-weibo', 'gems' ) ),
            array( 'icon-skype-with-circle' => esc_html__( 'Skype-with-circle', 'gems' ) ), array( 'icon-skype' => esc_html__( 'Skype', 'gems' ) ), array( 'icon-slideshare' => esc_html__( 'Slideshare', 'gems' ) ),
            array( 'icon-smashing' => esc_html__( 'Smashing', 'gems' ) ), array( 'icon-soundcloud' => esc_html__( 'Soundcloud', 'gems' ) ), array( 'icon-spotify-with-circle' => esc_html__( 'Spotify-with-circle', 'gems' ) ),
            array( 'icon-spotify' => esc_html__( 'Spotify', 'gems' ) ), array( 'icon-stumbleupon-with-circle' => esc_html__( 'Stumbleupon-with-circle', 'gems' ) ), array( 'icon-stumbleupon' => esc_html__( 'Stumbleupon', 'gems' ) ),
            array( 'icon-swarm' => esc_html__( 'Swarm', 'gems' ) ), array( 'icon-tripadvisor' => esc_html__( 'Tripadvisor', 'gems' ) ), array( 'icon-tumblr-with-circle' => esc_html__( 'Tumblr-with-circle', 'gems' ) ),
            array( 'icon-tumblr' => esc_html__( 'Tumblr', 'gems' ) ), array( 'icon-twitter-with-circle' => esc_html__( 'Twitter-with-circle', 'gems' ) ), array( 'icon-twitter' => esc_html__( 'Twitter', 'gems' ) ),
            array( 'icon-vimeo-with-circle' => esc_html__( 'Vimeo-with-circle', 'gems' ) ), array( 'icon-vimeo' => esc_html__( 'Vimeo', 'gems' ) ), array( 'icon-vine-with-circle' => esc_html__( 'Vine-with-circle', 'gems' ) ),
            array( 'icon-vine' => esc_html__( 'Vine', 'gems' ) ), array( 'icon-vk-alternitive' => esc_html__( 'Vk-alternitive', 'gems' ) ), array( 'icon-vk-with-circle' => esc_html__( 'Vk-with-circle', 'gems' ) ),
            array( 'icon-vk' => esc_html__( 'Vk', 'gems' ) ), array( 'icon-windows-store' => esc_html__( 'Windows-store', 'gems' ) ), array( 'icon-xing-with-circle' => esc_html__( 'Xing-with-circle', 'gems' ) ),
            array( 'icon-xing' => esc_html__( 'Xing', 'gems' ) ), array( 'icon-yelp' => esc_html__( 'Yelp', 'gems' ) ), array( 'icon-youko-with-circle' => esc_html__( 'Youko-with-circle', 'gems' ) ),
            array( 'icon-youko' => esc_html__( 'Youko', 'gems' ) ), array( 'icon-youtube-with-circle' => esc_html__( 'Youtube-with-circle', 'gems' ) ), array( 'icon-youtube' => esc_html__( 'Youtube', 'gems' ) ),
        );

        return $icons;
    }

}